import "./chunk-AZYDTFVW.js";
import "./chunk-XHAXZQZK.js";
import "./chunk-GBQ42ZDA.js";
import {
  TablePage
} from "./chunk-JSGSR4RJ.js";
import "./chunk-7CDOLCSU.js";
import {
  DesignationToLabel
} from "./chunk-INWUBHFN.js";
import "./chunk-P3SED4PH.js";
import "./chunk-EA2TUCZW.js";
import "./chunk-3JQ4HF4T.js";
import {
  Form
} from "./chunk-Y4CBTB76.js";
import {
  FlowsApi
} from "./chunk-SRK74APZ.js";
import "./chunk-WYSJXYDA.js";
import "./chunk-2GU5BCBP.js";
import "./chunk-UX7TDHO2.js";
import "./chunk-DK5NYREA.js";
import "./chunk-43ID2PET.js";
import "./chunk-ITYWTYEW.js";
import "./chunk-WCAXL5N5.js";
import "./chunk-EEANTJCZ.js";
import {
  description_list_default
} from "./chunk-DJQHOO67.js";
import {
  TableColumn
} from "./chunk-APZGZXW5.js";
import "./chunk-K3AR7TXW.js";
import "./chunk-RBLHQ2MQ.js";
import "./chunk-ADUGFWT2.js";
import {
  AndNext,
  DEFAULT_CONFIG,
  SentryIgnoredError,
  groupBy,
  n,
  r,
  t
} from "./chunk-MKGIUSP2.js";
import {
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/flows/FlowImportForm.ts
var FlowImportForm = class extends Form {
  getSuccessMessage() {
    return msg("Successfully imported flow.");
  }
  static get styles() {
    return super.styles.concat(description_list_default);
  }
  async send() {
    const file = this.getFormFiles()["flow"];
    if (!file) {
      throw new SentryIgnoredError("No form data");
    }
    const result = await new FlowsApi(DEFAULT_CONFIG).flowsInstancesImportCreate({
      file
    });
    if (!result.success) {
      this.result = result;
      throw new SentryIgnoredError("Failed to import flow");
    }
    return result;
  }
  renderResult() {
    return ke`
            <ak-form-element-horizontal label=${msg("Successful")}>
                <div class="pf-c-form__group-label">
                    <div class="c-form__horizontal-group">
                        <span class="pf-c-form__label-text">
                            <ak-status-label ?good=${this.result?.success}></ak-status-label>
                        </span>
                    </div>
                </div>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Log messages")}>
                <div class="pf-c-form__group-label">
                    <div class="c-form__horizontal-group">
                        <dl class="pf-c-description-list pf-m-horizontal">
                            <ak-log-viewer .logs=${this.result?.logs}></ak-log-viewer>
                        </dl>
                    </div>
                </div>
            </ak-form-element-horizontal>
        `;
  }
  renderForm() {
    return ke`<ak-form-element-horizontal label=${msg("Flow")} name="flow">
                <input type="file" value="" class="pf-c-form-control" />
                <p class="pf-c-form__helper-text">
                    ${msg(
      ".yaml files, which can be found on goauthentik.io and can be exported by authentik."
    )}
                </p>
            </ak-form-element-horizontal>
            ${this.result ? this.renderResult() : ke``}`;
  }
};
__decorateClass([
  r()
], FlowImportForm.prototype, "result", 2);
FlowImportForm = __decorateClass([
  t("ak-flow-import-form")
], FlowImportForm);

// src/admin/flows/FlowListPage.ts
var FlowListPage = class extends TablePage {
  constructor() {
    super(...arguments);
    this.checkbox = true;
    this.clearOnRefresh = true;
    this.order = "slug";
  }
  searchEnabled() {
    return true;
  }
  pageTitle() {
    return msg("Flows");
  }
  pageDescription() {
    return msg(
      "Flows describe a chain of Stages to authenticate, enroll or recover a user. Stages are chosen based on policies applied to them."
    );
  }
  pageIcon() {
    return "pf-icon pf-icon-process-automation";
  }
  async apiEndpoint() {
    return new FlowsApi(DEFAULT_CONFIG).flowsInstancesList(await this.defaultEndpointConfig());
  }
  groupBy(items) {
    return groupBy(items, (flow) => {
      return DesignationToLabel(flow.designation);
    });
  }
  columns() {
    return [
      new TableColumn(msg("Identifier"), "slug"),
      new TableColumn(msg("Name"), "name"),
      new TableColumn(msg("Stages")),
      new TableColumn(msg("Policies")),
      new TableColumn(msg("Actions"))
    ];
  }
  renderToolbarSelected() {
    const disabled = this.selectedElements.length < 1;
    return ke`<ak-forms-delete-bulk
            objectLabel=${msg("Flow(s)")}
            .objects=${this.selectedElements}
            .usedBy=${(item) => {
      return new FlowsApi(DEFAULT_CONFIG).flowsInstancesUsedByList({
        slug: item.slug
      });
    }}
            .delete=${(item) => {
      return new FlowsApi(DEFAULT_CONFIG).flowsInstancesDestroy({
        slug: item.slug
      });
    }}
        >
            <button ?disabled=${disabled} slot="trigger" class="pf-c-button pf-m-danger">
                ${msg("Delete")}
            </button>
        </ak-forms-delete-bulk>`;
  }
  row(item) {
    return [
      ke`<div>
                    <a href="#/flow/flows/${item.slug}">
                        <code>${item.slug}</code>
                    </a>
                </div>
                <small>${item.title}</small>`,
      ke`${item.name}`,
      ke`${Array.from(item.stages || []).length}`,
      ke`${Array.from(item.policies || []).length}`,
      ke` <ak-forms-modal>
                    <span slot="submit"> ${msg("Update")} </span>
                    <span slot="header"> ${msg("Update Flow")} </span>
                    <ak-flow-form slot="form" .instancePk=${item.slug}> </ak-flow-form>
                    <button slot="trigger" class="pf-c-button pf-m-plain">
                        <pf-tooltip position="top" content=${msg("Edit")}>
                            <i class="fas fa-edit"></i>
                        </pf-tooltip>
                    </button>
                </ak-forms-modal>
                <button
                    class="pf-c-button pf-m-plain"
                    @click=${() => {
        const finalURL = `${window.location.origin}/if/flow/${item.slug}/${AndNext(
          `${window.location.pathname}#${window.location.hash}`
        )}`;
        window.open(finalURL, "_blank");
      }}
                >
                    <pf-tooltip position="top" content=${msg("Execute")}>
                        <i class="fas fa-play" aria-hidden="true"></i>
                    </pf-tooltip>
                </button>
                <a class="pf-c-button pf-m-plain" href=${item.exportUrl}>
                    <pf-tooltip position="top" content=${msg("Export")}>
                        <i class="fas fa-download"></i>
                    </pf-tooltip>
                </a>`
    ];
  }
  renderObjectCreate() {
    return ke`
            <ak-forms-modal>
                <span slot="submit"> ${msg("Create")} </span>
                <span slot="header"> ${msg("Create Flow")} </span>
                <ak-flow-form slot="form"> </ak-flow-form>
                <button slot="trigger" class="pf-c-button pf-m-primary">${msg("Create")}</button>
            </ak-forms-modal>
            <ak-forms-modal>
                <span slot="submit"> ${msg("Import")} </span>
                <span slot="header"> ${msg("Import Flow")} </span>
                <ak-flow-import-form slot="form"> </ak-flow-import-form>
                <button slot="trigger" class="pf-c-button pf-m-primary">${msg("Import")}</button>
            </ak-forms-modal>
        `;
  }
  renderToolbar() {
    return ke`
            ${super.renderToolbar()}
            <ak-forms-confirm
                successMessage=${msg("Successfully cleared flow cache")}
                errorMessage=${msg("Failed to delete flow cache")}
                action=${msg("Clear cache")}
                .onConfirm=${() => {
      return new FlowsApi(DEFAULT_CONFIG).flowsInstancesCacheClearCreate();
    }}
            >
                <span slot="header"> ${msg("Clear Flow cache")} </span>
                <p slot="body">
                    ${msg(
      `Are you sure you want to clear the flow cache?
            This will cause all flows to be re-evaluated on their next usage.`
    )}
                </p>
                <button slot="trigger" class="pf-c-button pf-m-secondary" type="button">
                    ${msg("Clear cache")}
                </button>
                <div slot="modal"></div>
            </ak-forms-confirm>
        `;
  }
};
__decorateClass([
  n()
], FlowListPage.prototype, "order", 2);
FlowListPage = __decorateClass([
  t("ak-flow-list")
], FlowListPage);
export {
  FlowListPage
};
//# sourceMappingURL=FlowListPage-HBMFP5RK.js.map
