import {
  PropertymappingsApi
} from "./chunk-TM5VGYRQ.js";
import {
  FlowSearch_default
} from "./chunk-Q2C4IWV3.js";
import {
  AkControlElement
} from "./chunk-SXPKNFZF.js";
import {
  ModelForm
} from "./chunk-3JQ4HF4T.js";
import {
  ProvidersApi
} from "./chunk-3PUBL4VQ.js";
import {
  SourcesApi
} from "./chunk-TBCAGHBB.js";
import {
  FlowsInstancesListDesignationEnum
} from "./chunk-SRK74APZ.js";
import {
  form_control_default,
  input_group_default
} from "./chunk-APZGZXW5.js";
import {
  spread
} from "./chunk-ADUGFWT2.js";
import {
  ClientTypeEnum,
  CoreApi,
  DEFAULT_CONFIG,
  DigestAlgorithmEnum,
  IssuerModeEnum,
  LDAPAPIAccessMode,
  MatchingModeEnum,
  ProxyMode,
  SignatureAlgorithmEnum,
  SpBindingEnum,
  SubModeEnum,
  ascii_letters,
  digits,
  first,
  n,
  patternfly_base_default,
  r,
  r2,
  randomString,
  t,
  to,
  z
} from "./chunk-MKGIUSP2.js";
import {
  D,
  i,
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/providers/BaseProviderForm.ts
var BaseProviderForm = class extends ModelForm {
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated provider.") : msg("Successfully created provider.");
  }
};

// src/admin/providers/oauth2/OAuth2ProviderRedirectURI.ts
var OAuth2ProviderRedirectURI = class extends AkControlElement {
  constructor() {
    super(...arguments);
    this.redirectURI = {
      matchingMode: MatchingModeEnum.Strict,
      url: ""
    };
  }
  static get styles() {
    return [
      patternfly_base_default,
      input_group_default,
      form_control_default,
      i`
                .pf-c-input-group select {
                    width: 10em;
                }
            `
    ];
  }
  json() {
    return Object.fromEntries(
      Array.from(this.controls ?? []).map((control) => [control.name, control.value])
    );
  }
  get isValid() {
    return true;
  }
  render() {
    const onChange = () => {
      this.dispatchEvent(new Event("change", { composed: true, bubbles: true }));
    };
    return ke`<div class="pf-c-input-group">
            <select
                name="matchingMode"
                class="pf-c-form-control ak-form-control"
                @change=${onChange}
            >
                <option
                    value="${MatchingModeEnum.Strict}"
                    ?selected=${this.redirectURI.matchingMode === MatchingModeEnum.Strict}
                >
                    ${msg("Strict")}
                </option>
                <option
                    value="${MatchingModeEnum.Regex}"
                    ?selected=${this.redirectURI.matchingMode === MatchingModeEnum.Regex}
                >
                    ${msg("Regex")}
                </option>
            </select>
            <input
                type="text"
                @change=${onChange}
                value="${to(this.redirectURI.url ?? void 0)}"
                class="pf-c-form-control ak-form-control pf-m-monospace"
                spellcheck="false"
                autocomplete="off"
                required
                id="url"
                placeholder=${msg("URL")}
                name="url"
                tabindex="1"
            />
        </div>`;
  }
};
__decorateClass([
  n({ type: Object, attribute: false })
], OAuth2ProviderRedirectURI.prototype, "redirectURI", 2);
__decorateClass([
  r2(".ak-form-control")
], OAuth2ProviderRedirectURI.prototype, "controls", 2);
OAuth2ProviderRedirectURI = __decorateClass([
  t("ak-provider-oauth2-redirect-uri")
], OAuth2ProviderRedirectURI);
function akOAuthRedirectURIInput(properties) {
  return ke`<ak-provider-oauth2-redirect-uri
        ${spread(properties)}
    ></ak-provider-oauth2-redirect-uri>`;
}

// src/admin/providers/oauth2/OAuth2ProviderFormHelpers.ts
var defaultScopes = [
  "goauthentik.io/providers/oauth2/scope-openid",
  "goauthentik.io/providers/oauth2/scope-email",
  "goauthentik.io/providers/oauth2/scope-profile"
];
var mappingToSelect = (s) => [s.pk, s.name, s.name, s];
async function propertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderScopeList({
    ordering: "scope_name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect)
  };
}
function propertyMappingsSelector(instanceMappings) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(
      ([_0, _1, _2, scope]) => scope?.managed && defaultScopes.includes(scope?.managed)
    );
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsProviderScopeRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect);
  };
}

// src/admin/providers/oauth2/OAuth2ProvidersProvider.ts
var providerToSelect = (provider) => [provider.pk, provider.name];
async function oauth2ProvidersProvider(page = 1, search = "") {
  const oauthProviders = await new ProvidersApi(DEFAULT_CONFIG).providersOauth2List({
    ordering: "name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: oauthProviders.pagination,
    options: oauthProviders.results.map((provider) => providerToSelect(provider))
  };
}
function oauth2ProvidersSelector(instanceProviders) {
  if (!instanceProviders) {
    return async (mappings) => mappings.filter(
      ([_0, _1, _2, source]) => source !== void 0
    );
  }
  return async () => {
    const oauthSources = new ProvidersApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceProviders.map(
        (instanceId) => oauthSources.providersOauth2Retrieve({ id: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(providerToSelect);
  };
}

// src/admin/providers/oauth2/OAuth2Sources.ts
var sourceToSelect = (source) => [
  source.pk,
  `${source.name} (${source.slug})`,
  source.name,
  source
];
async function oauth2SourcesProvider(page = 1, search = "") {
  const oauthSources = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthList({
    ordering: "name",
    hasJwks: true,
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: oauthSources.pagination,
    options: oauthSources.results.map(sourceToSelect)
  };
}
function oauth2SourcesSelector(instanceMappings) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(
      ([_0, _1, _2, source]) => source !== void 0
    );
  }
  return async () => {
    const oauthSources = new SourcesApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => oauthSources.sourcesOauthList({ pbmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).filter((s) => s.pagination.count > 0).map((s) => s.results[0]).map(sourceToSelect);
  };
}

// src/admin/providers/oauth2/OAuth2ProviderFormForm.ts
var clientTypeOptions = [
  {
    label: msg("Confidential"),
    value: ClientTypeEnum.Confidential,
    default: true,
    description: ke`${msg(
      "Confidential clients are capable of maintaining the confidentiality of their credentials such as client secrets"
    )}`
  },
  {
    label: msg("Public"),
    value: ClientTypeEnum.Public,
    description: ke`${msg(
      "Public clients are incapable of maintaining the confidentiality and should use methods like PKCE. "
    )}`
  }
];
var subjectModeOptions = [
  {
    label: msg("Based on the User's hashed ID"),
    value: SubModeEnum.HashedUserId,
    default: true
  },
  {
    label: msg("Based on the User's ID"),
    value: SubModeEnum.UserId
  },
  {
    label: msg("Based on the User's UUID"),
    value: SubModeEnum.UserUuid
  },
  {
    label: msg("Based on the User's username"),
    value: SubModeEnum.UserUsername
  },
  {
    label: msg("Based on the User's Email"),
    value: SubModeEnum.UserEmail,
    description: ke`${msg("This is recommended over the UPN mode.")}`
  },
  {
    label: msg("Based on the User's UPN"),
    value: SubModeEnum.UserUpn,
    description: ke`${msg(
      "Requires the user to have a 'upn' attribute set, and falls back to hashed user ID. Use this mode only if you have different UPN and Mail domains."
    )}`
  }
];
var issuerModeOptions = [
  {
    label: msg("Each provider has a different issuer, based on the application slug"),
    value: IssuerModeEnum.PerProvider,
    default: true
  },
  {
    label: msg("Same identifier is used for all providers"),
    value: IssuerModeEnum.Global
  }
];
var redirectUriHelpMessages = [
  msg(
    "Valid redirect URIs after a successful authorization flow. Also specify any origins here for Implicit flows."
  ),
  msg(
    "If no explicit redirect URIs are specified, the first successfully used redirect URI will be saved."
  ),
  msg(
    'To allow any redirect URI, set the mode to Regex and the value to ".*". Be aware of the possible security implications this can have.'
  )
];
var redirectUriHelp = ke`${redirectUriHelpMessages.map(
  (m) => ke`<p class="pf-c-form__helper-text">${m}</p>`
)}`;
var defaultShowClientSecret = (_show) => void 0;
function renderForm(provider, errors, showClientSecret = false, showClientSecretCallback = defaultShowClientSecret) {
  return ke` <ak-text-input
            name="name"
            label=${msg("Name")}
            value=${to(provider?.name)}
            required
        ></ak-text-input>

        <ak-form-element-horizontal
            name="authorizationFlow"
            label=${msg("Authorization flow")}
            ?required=${true}
        >
            <ak-flow-search
                flowType=${FlowsInstancesListDesignationEnum.Authorization}
                .currentFlow=${provider?.authorizationFlow}
                required
            ></ak-flow-search>
            <p class="pf-c-form__helper-text">
                ${msg("Flow used when authorizing this provider.")}
            </p>
        </ak-form-element-horizontal>
        <ak-form-group expanded>
            <span slot="header"> ${msg("Protocol settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-radio-input
                    name="clientType"
                    label=${msg("Client type")}
                    .value=${provider?.clientType}
                    required
                    @change=${(ev) => {
    showClientSecretCallback(ev.detail.value !== ClientTypeEnum.Public);
  }}
                    .options=${clientTypeOptions}
                >
                </ak-radio-input>
                <ak-text-input
                    name="clientId"
                    label=${msg("Client ID")}
                    value="${first(provider?.clientId, randomString(40, ascii_letters + digits))}"
                    required
                    inputHint="code"
                >
                </ak-text-input>
                <ak-text-input
                    name="clientSecret"
                    label=${msg("Client Secret")}
                    value="${first(
    provider?.clientSecret,
    randomString(128, ascii_letters + digits)
  )}"
                    inputHint="code"
                    ?hidden=${!showClientSecret}
                >
                </ak-text-input>
                <ak-form-element-horizontal
                    label=${msg("Redirect URIs/Origins (RegEx)")}
                    required
                    name="redirectUris"
                >
                    <ak-array-input
                        .items=${provider?.redirectUris ?? []}
                        .newItem=${() => ({ matchingMode: MatchingModeEnum.Strict, url: "" })}
                        .row=${(f) => akOAuthRedirectURIInput({
    ".redirectURI": f,
    "style": "width: 100%",
    "name": "oauth2-redirect-uri"
  })}
                    >
                    </ak-array-input>
                    ${redirectUriHelp}
                </ak-form-element-horizontal>

                <ak-form-element-horizontal label=${msg("Signing Key")} name="signingKey">
                    <!-- NOTE: 'null' cast to 'undefined' on signingKey to satisfy Lit requirements -->
                    <ak-crypto-certificate-search
                        certificate=${to(provider?.signingKey ?? void 0)}
                        singleton
                    ></ak-crypto-certificate-search>
                    <p class="pf-c-form__helper-text">${msg("Key used to sign the tokens.")}</p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal label=${msg("Encryption Key")} name="encryptionKey">
                    <!-- NOTE: 'null' cast to 'undefined' on encryptionKey to satisfy Lit requirements -->
                    <ak-crypto-certificate-search
                        certificate=${to(provider?.encryptionKey ?? void 0)}
                    ></ak-crypto-certificate-search>
                    <p class="pf-c-form__helper-text">${msg("Key used to encrypt the tokens.")}</p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>

        <ak-form-group>
            <span slot="header"> ${msg("Advanced flow settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    name="authenticationFlow"
                    label=${msg("Authentication flow")}
                >
                    <ak-flow-search
                        flowType=${FlowsInstancesListDesignationEnum.Authentication}
                        .currentFlow=${provider?.authenticationFlow}
                    ></ak-flow-search>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "Flow used when a user access this provider and is not authenticated."
  )}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Invalidation flow")}
                    name="invalidationFlow"
                    required
                >
                    <ak-flow-search
                        flowType=${FlowsInstancesListDesignationEnum.Invalidation}
                        .currentFlow=${provider?.invalidationFlow}
                        defaultFlowSlug="default-provider-invalidation-flow"
                        required
                    ></ak-flow-search>
                    <p class="pf-c-form__helper-text">
                        ${msg("Flow used when logging out of this provider.")}
                    </p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>

        <ak-form-group>
            <span slot="header"> ${msg("Advanced protocol settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-text-input
                    name="accessCodeValidity"
                    label=${msg("Access code validity")}
                    inputHint="code"
                    required
                    value="${first(provider?.accessCodeValidity, "minutes=1")}"
                    .bighelp=${ke`<p class="pf-c-form__helper-text">
                            ${msg("Configure how long access codes are valid for.")}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>`}
                >
                </ak-text-input>
                <ak-text-input
                    name="accessTokenValidity"
                    label=${msg("Access Token validity")}
                    value="${first(provider?.accessTokenValidity, "minutes=5")}"
                    inputHint="code"
                    required
                    .bighelp=${ke` <p class="pf-c-form__helper-text">
                            ${msg("Configure how long access tokens are valid for.")}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>`}
                >
                </ak-text-input>

                <ak-text-input
                    name="refreshTokenValidity"
                    label=${msg("Refresh Token validity")}
                    value="${first(provider?.refreshTokenValidity, "days=30")}"
                    inputHint="code"
                    ?required=${true}
                    .bighelp=${ke` <p class="pf-c-form__helper-text">
                            ${msg("Configure how long refresh tokens are valid for.")}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>`}
                >
                </ak-text-input>
                <ak-form-element-horizontal label=${msg("Scopes")} name="propertyMappings">
                    <ak-dual-select-dynamic-selected
                        .provider=${propertyMappingsProvider}
                        .selector=${propertyMappingsSelector(provider?.propertyMappings)}
                        available-label=${msg("Available Scopes")}
                        selected-label=${msg("Selected Scopes")}
                    ></ak-dual-select-dynamic-selected>

                    <p class="pf-c-form__helper-text">
                        ${msg(
    "Select which scopes can be used by the client. The client still has to specify the scope to access the data."
  )}
                    </p>
                </ak-form-element-horizontal>
                <ak-radio-input
                    name="subMode"
                    label=${msg("Subject mode")}
                    required
                    .options=${subjectModeOptions}
                    .value=${provider?.subMode}
                    help=${msg(
    "Configure what data should be used as unique User Identifier. For most cases, the default should be fine."
  )}
                >
                </ak-radio-input>
                <ak-switch-input
                    name="includeClaimsInIdToken"
                    label=${msg("Include claims in id_token")}
                    ?checked=${first(provider?.includeClaimsInIdToken, true)}
                    help=${msg(
    "Include User claims from scopes in the id_token, for applications that don't access the userinfo endpoint."
  )}
                ></ak-switch-input>
                <ak-radio-input
                    name="issuerMode"
                    label=${msg("Issuer mode")}
                    required
                    .options=${issuerModeOptions}
                    .value=${provider?.issuerMode}
                    help=${msg("Configure how the issuer field of the ID Token should be filled.")}
                >
                </ak-radio-input>
            </div>
        </ak-form-group>

        <ak-form-group>
            <span slot="header">${msg("Machine-to-Machine authentication settings")}</span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    label=${msg("Federated OIDC Sources")}
                    name="jwtFederationSources"
                >
                    <ak-dual-select-dynamic-selected
                        .provider=${oauth2SourcesProvider}
                        .selector=${oauth2SourcesSelector(provider?.jwtFederationSources)}
                        available-label=${msg("Available Sources")}
                        selected-label=${msg("Selected Sources")}
                    ></ak-dual-select-dynamic-selected>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "JWTs signed by certificates configured in the selected sources can be used to authenticate to this provider."
  )}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Federated OIDC Providers")}
                    name="jwtFederationProviders"
                >
                    <ak-dual-select-dynamic-selected
                        .provider=${oauth2ProvidersProvider}
                        .selector=${oauth2ProvidersSelector(provider?.jwtFederationProviders)}
                        available-label=${msg("Available Providers")}
                        selected-label=${msg("Selected Providers")}
                    ></ak-dual-select-dynamic-selected>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "JWTs signed by the selected providers can be used to authenticate to this provider."
  )}
                    </p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>`;
}

// src/admin/providers/oauth2/OAuth2ProviderForm.ts
var providerToSelect2 = (provider) => [provider.pk, provider.name];
async function oauth2ProvidersProvider2(page = 1, search = "") {
  const oauthProviders = await new ProvidersApi(DEFAULT_CONFIG).providersOauth2List({
    ordering: "name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: oauthProviders.pagination,
    options: oauthProviders.results.map((provider) => providerToSelect2(provider))
  };
}
function oauth2ProviderSelector(instanceProviders) {
  if (!instanceProviders) {
    return async (mappings) => mappings.filter(
      ([_0, _1, _2, source]) => source !== void 0
    );
  }
  return async () => {
    const oauthSources = new ProvidersApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceProviders.map(
        (instanceId) => oauthSources.providersOauth2Retrieve({ id: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(providerToSelect2);
  };
}
var OAuth2ProviderFormPage = class extends BaseProviderForm {
  constructor() {
    super(...arguments);
    this.showClientSecret = true;
  }
  static get styles() {
    return super.styles.concat(i`
            ak-array-input {
                width: 100%;
            }
        `);
  }
  async loadInstance(pk) {
    const provider = await new ProvidersApi(DEFAULT_CONFIG).providersOauth2Retrieve({
      id: pk
    });
    this.showClientSecret = provider.clientType === ClientTypeEnum.Confidential;
    return provider;
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersOauth2Update({
        id: this.instance.pk,
        oAuth2ProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersOauth2Create({
        oAuth2ProviderRequest: data
      });
    }
  }
  renderForm() {
    const showClientSecretCallback = (show) => {
      this.showClientSecret = show;
    };
    return renderForm(this.instance ?? {}, [], this.showClientSecret, showClientSecretCallback);
  }
};
__decorateClass([
  r()
], OAuth2ProviderFormPage.prototype, "showClientSecret", 2);
OAuth2ProviderFormPage = __decorateClass([
  t("ak-provider-oauth2-form")
], OAuth2ProviderFormPage);

// src/admin/common/ak-flow-search/ak-branded-flow-search.ts
var AkBrandedFlowSearch = class extends FlowSearch_default {
  constructor() {
    super();
    this.selected = this.selected.bind(this);
  }
  selected(flow) {
    return super.selected(flow) || flow.pk === this.brandFlow;
  }
};
__decorateClass([
  n({ attribute: false, type: String })
], AkBrandedFlowSearch.prototype, "brandFlow", 2);
AkBrandedFlowSearch = __decorateClass([
  t("ak-branded-flow-search")
], AkBrandedFlowSearch);

// src/admin/providers/ldap/LDAPOptionsAndHelp.ts
var bindModeOptions = [
  {
    label: msg("Cached binding"),
    value: LDAPAPIAccessMode.Cached,
    default: true,
    description: ke`${msg(
      "Flow is executed and session is cached in memory. Flow is executed when session expires"
    )}`
  },
  {
    label: msg("Direct binding"),
    value: LDAPAPIAccessMode.Direct,
    description: ke`${msg(
      "Always execute the configured bind flow to authenticate the user"
    )}`
  }
];
var searchModeOptions = [
  {
    label: msg("Cached querying"),
    value: LDAPAPIAccessMode.Cached,
    default: true,
    description: ke`${msg(
      "The outpost holds all users and groups in-memory and will refresh every 5 Minutes"
    )}`
  },
  {
    label: msg("Direct querying"),
    value: LDAPAPIAccessMode.Direct,
    description: ke`${msg(
      "Always returns the latest data, but slower than cached querying"
    )}`
  }
];
var mfaSupportHelp = msg(
  "When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon."
);
var cryptoCertificateHelp = msg(
  "The certificate for the above configured Base DN. As a fallback, the provider uses a self-signed certificate."
);
var tlsServerNameHelp = msg(
  "DNS name for which the above configured certificate should be used. The certificate cannot be detected based on the base DN, as the SSL/TLS negotiation happens before such data is exchanged."
);
var uidStartNumberHelp = msg(
  "The start for uidNumbers, this number is added to the user.Pk to make sure that the numbers aren't too low for POSIX users. Default is 2000 to ensure that we don't collide with local users uidNumber"
);
var gidStartNumberHelp = msg(
  "The start for gidNumbers, this number is added to a number generated from the group.Pk to make sure that the numbers aren't too low for POSIX groups. Default is 4000 to ensure that we don't collide with local groups or users primary groups gidNumber"
);

// src/admin/providers/ldap/LDAPProviderFormForm.ts
function renderForm2(provider, errors = {}, brand) {
  return ke`
        <ak-text-input
            name="name"
            value=${to(provider?.name)}
            label=${msg("Name")}
            .errorMessages=${errors?.name ?? []}
            required
            help=${msg("Method's display Name.")}
        ></ak-text-input>
        <ak-radio-input
            label=${msg("Bind mode")}
            name="bindMode"
            .options=${bindModeOptions}
            .value=${provider?.bindMode}
            help=${msg("Configure how the outpost authenticates requests.")}
        >
        </ak-radio-input>

        <ak-radio-input
            label=${msg("Search mode")}
            name="searchMode"
            .options=${searchModeOptions}
            .value=${provider?.searchMode}
            help=${msg("Configure how the outpost queries the core authentik server's users.")}
        >
        </ak-radio-input>

        <ak-switch-input
            name="mfaSupport"
            label=${msg("Code-based MFA Support")}
            ?checked=${provider?.mfaSupport ?? true}
            help=${mfaSupportHelp}
        >
        </ak-switch-input>

        <ak-form-group expanded>
            <span slot="header"> ${msg("Flow settings")} </span>

            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    label=${msg("Bind flow")}
                    ?required=${true}
                    name="authorizationFlow"
                    .errorMessages=${errors?.authorizationFlow ?? []}
                >
                    <ak-branded-flow-search
                        flowType=${FlowsInstancesListDesignationEnum.Authentication}
                        .currentFlow=${provider?.authorizationFlow}
                        .brandFlow=${brand?.flowAuthentication}
                        required
                    ></ak-branded-flow-search>
                    <p class="pf-c-form__helper-text">
                        ${msg("Flow used for users to authenticate.")}
                    </p>
                </ak-form-element-horizontal>

                <ak-form-element-horizontal
                    label=${msg("Unbind flow")}
                    name="invalidationFlow"
                    required
                >
                    <ak-branded-flow-search
                        flowType=${FlowsInstancesListDesignationEnum.Invalidation}
                        .currentFlow=${provider?.invalidationFlow}
                        .brandFlow=${brand?.flowInvalidation}
                        defaultFlowSlug="default-invalidation-flow"
                        .errorMessages=${errors?.invalidationFlow ?? []}
                        required
                    ></ak-branded-flow-search>
                    <p class="pf-c-form__helper-text">${msg("Flow used for unbinding users.")}</p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>

        <ak-form-group expanded>
            <span slot="header"> ${msg("Protocol settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-text-input
                    name="baseDn"
                    label=${msg("Base DN")}
                    required
                    value="${provider?.baseDn ?? "DC=ldap,DC=goauthentik,DC=io"}"
                    inputHint="code"
                    .errorMessages=${errors?.baseDn ?? []}
                    help=${msg(
    "LDAP DN under which bind requests and search requests can be made."
  )}
                >
                </ak-text-input>

                <ak-form-element-horizontal
                    label=${msg("Certificate")}
                    name="certificate"
                    .errorMessages=${errors?.certificate ?? []}
                >
                    <ak-crypto-certificate-search
                        certificate=${to(provider?.certificate ?? D)}
                        name="certificate"
                    >
                    </ak-crypto-certificate-search>
                    <p class="pf-c-form__helper-text">${cryptoCertificateHelp}</p>
                </ak-form-element-horizontal>

                <ak-text-input
                    label=${msg("TLS Server name")}
                    name="tlsServerName"
                    value="${provider?.tlsServerName ?? ""}"
                    .errorMessages=${errors?.tlsServerName ?? []}
                    help=${tlsServerNameHelp}
                    inputHint="code"
                ></ak-text-input>

                <ak-number-input
                    label=${msg("UID start number")}
                    required
                    name="uidStartNumber"
                    value="${provider?.uidStartNumber ?? 2e3}"
                    .errorMessages=${errors?.uidStartNumber ?? []}
                    help=${uidStartNumberHelp}
                ></ak-number-input>

                <ak-number-input
                    label=${msg("GID start number")}
                    required
                    name="gidStartNumber"
                    value="${provider?.gidStartNumber ?? 4e3}"
                    .errorMessages=${errors?.gidStartNumber ?? []}
                    help=${gidStartNumberHelp}
                ></ak-number-input>
            </div>
        </ak-form-group>
    `;
}

// src/admin/providers/proxy/ProxyProviderFormHelpers.ts
var mappingToSelect2 = (s) => [s.pk, s.name, s.name, s];
async function propertyMappingsProvider2(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderScopeList({
    ordering: "scope_name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect2)
  };
}
function propertyMappingsSelector2(instanceMappings) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(
      ([_0, _1, _2, scope]) => !(scope?.managed ?? "").startsWith("goauthentik.io/providers")
    );
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsProviderScopeRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect2);
  };
}

// src/admin/providers/proxy/ProxyProviderFormForm.ts
function renderHttpBasic(provider) {
  return ke`<ak-text-input
            name="basicAuthUserAttribute"
            label=${msg("HTTP-Basic Username Key")}
            value="${to(provider?.basicAuthUserAttribute)}"
            help=${msg(
    "User/Group Attribute used for the user part of the HTTP-Basic Header. If not set, the user's Email address is used."
  )}
            inputHint="code"
        >
        </ak-text-input>

        <ak-text-input
            name="basicAuthPasswordAttribute"
            label=${msg("HTTP-Basic Password Key")}
            value="${to(provider?.basicAuthPasswordAttribute)}"
            help=${msg("User/Group Attribute used for the password part of the HTTP-Basic Header.")}
            inputHint="code"
        >
        </ak-text-input>`;
}
function renderModeSelector(mode, onSet) {
  return ke` <ak-toggle-group
        value=${mode}
        @ak-toggle=${onSet}
        data-ouid-component-name="proxy-type-toggle"
    >
        <option value=${ProxyMode.Proxy}>${msg("Proxy")}</option>
        <option value=${ProxyMode.ForwardSingle}>${msg("Forward auth (single application)")}</option>
        <option value=${ProxyMode.ForwardDomain}>${msg("Forward auth (domain level)")}</option>
    </ak-toggle-group>`;
}
function renderProxySettings(provider, errors) {
  return ke`<p class="pf-u-mb-xl">
            ${msg(
    "This provider will behave like a transparent reverse-proxy, except requests must be authenticated. If your upstream application uses HTTPS, make sure to connect to the outpost using HTTPS as well."
  )}
        </p>
        <ak-text-input
            name="externalHost"
            label=${msg("External host")}
            value="${to(provider?.externalHost)}"
            required
            .errorMessages=${errors?.externalHost ?? []}
            help=${msg(
    "The external URL you'll access the application at. Include any non-standard port."
  )}
            inputHint="code"
        ></ak-text-input>
        <ak-text-input
            name="internalHost"
            label=${msg("Internal host")}
            value="${to(provider?.internalHost)}"
            required
            .errorMessages=${errors?.internalHost ?? []}
            help=${msg("Upstream host that the requests are forwarded to.")}
            inputHint="code"
        ></ak-text-input>

        <ak-switch-input
            name="internalHostSslValidation"
            label=${msg("Internal host SSL Validation")}
            ?checked=${provider?.internalHostSslValidation ?? true}
            help=${msg("Validate SSL Certificates of upstream servers.")}
        >
        </ak-switch-input>`;
}
function renderForwardSingleSettings(provider, errors) {
  return ke`<p class="pf-u-mb-xl">
            ${msg(
    "Use this provider with nginx's auth_request or traefik's forwardAuth. Each application/domain needs its own provider. Additionally, on each domain, /outpost.goauthentik.io must be routed to the outpost (when using a managed outpost, this is done for you)."
  )}
        </p>
        <ak-text-input
            name="externalHost"
            label=${msg("External host")}
            value="${to(provider?.externalHost)}"
            required
            .errorMessages=${errors?.externalHost ?? []}
            help=${msg(
    "The external URL you'll access the application at. Include any non-standard port."
  )}
            inputHint="code"
        ></ak-text-input>`;
}
function renderForwardDomainSettings(provider, errors) {
  return ke`<p class="pf-u-mb-xl">
            ${msg(
    "Use this provider with nginx's auth_request or traefik's forwardAuth. Only a single provider is required per root domain. You can't do per-application authorization, but you don't have to create a provider for each application."
  )}
        </p>
        <div class="pf-u-mb-xl">
            ${msg("An example setup can look like this:")}
            <ul class="pf-c-list">
                <li>${msg("authentik running on auth.example.com")}</li>
                <li>${msg("app1 running on app1.example.com")}</li>
            </ul>
            ${msg(
    "In this case, you'd set the Authentication URL to auth.example.com and Cookie domain to example.com."
  )}
        </div>

        <ak-text-input
            name="externalHost"
            label=${msg("Authentication URL")}
            value="${provider?.externalHost ?? window.location.origin}"
            required
            .errorMessages=${errors?.externalHost ?? []}
            help=${msg(
    "The external URL you'll authenticate at. The authentik core server should be reachable under this URL."
  )}
        ></ak-text-input>

        <ak-text-input
            label=${msg("Cookie domain")}
            name="cookieDomain"
            value="${to(provider?.cookieDomain)}"
            required
            .errorMessages=${errors?.cookieDomain ?? []}
            help=${msg(
    "Set this to the domain you wish the authentication to be valid for. Must be a parent domain of the URL above. If you're running applications as app1.domain.tld, app2.domain.tld, set this to 'domain.tld'."
  )}
        ></ak-text-input> `;
}
function renderSettings(provider, mode) {
  return z(mode).with(ProxyMode.Proxy, () => renderProxySettings(provider)).with(ProxyMode.ForwardSingle, () => renderForwardSingleSettings(provider)).with(ProxyMode.ForwardDomain, () => renderForwardDomainSettings(provider)).otherwise(() => {
    throw new Error("Unrecognized proxy mode");
  });
}
function renderForm3(provider = {}, errors = {}, args) {
  const { mode, onSetMode, showHttpBasic, onSetShowHttpBasic } = args;
  return ke`
        <ak-text-input
            name="name"
            value=${to(provider?.name)}
            label=${msg("Name")}
            .errorMessages=${errors?.name ?? []}
            required
        ></ak-text-input>

        <ak-form-element-horizontal
            label=${msg("Authorization flow")}
            required
            name="authorizationFlow"
        >
            <ak-flow-search
                flowType=${FlowsInstancesListDesignationEnum.Authorization}
                .currentFlow=${provider?.authorizationFlow}
                required
            ></ak-flow-search>
            <p class="pf-c-form__helper-text">
                ${msg("Flow used when authorizing this provider.")}
            </p>
        </ak-form-element-horizontal>

        <div class="pf-c-card pf-m-selectable pf-m-selected">
            <div class="pf-c-card__body">${renderModeSelector(mode, onSetMode)}</div>
            <div class="pf-c-card__footer">${renderSettings(provider, mode)}</div>
        </div>

        <ak-text-input
            label=${msg("Token validity")}
            name="accessTokenValidity"
            value="${provider?.accessTokenValidity ?? "hours=24"}"
            .errorMessages=${errors?.accessTokenValidity ?? []}
            required
            .help=${msg("Configure how long tokens are valid for.")}
            inputHint="code"
        ></ak-text-input>

        <ak-form-group>
            <span slot="header">${msg("Advanced protocol settings")}</span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal label=${msg("Certificate")} name="certificate">
                    <ak-crypto-certificate-search
                        .certificate=${provider?.certificate}
                    ></ak-crypto-certificate-search>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Additional scopes")}
                    name="propertyMappings"
                >
                    <ak-dual-select-dynamic-selected
                        .provider=${propertyMappingsProvider2}
                        .selector=${propertyMappingsSelector2(provider?.propertyMappings)}
                        available-label="${msg("Available Scopes")}"
                        selected-label="${msg("Selected Scopes")}"
                    ></ak-dual-select-dynamic-selected>
                    <p class="pf-c-form__helper-text">
                        ${msg("Additional scope mappings, which are passed to the proxy.")}
                    </p>
                </ak-form-element-horizontal>

                <ak-form-element-horizontal
                    label="${mode === ProxyMode.ForwardDomain ? msg("Unauthenticated URLs") : msg("Unauthenticated Paths")}"
                    name="skipPathRegex"
                >
                    <textarea class="pf-c-form-control pf-m-monospace">
${provider?.skipPathRegex}</textarea
                    >
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "Regular expressions for which authentication is not required. Each new line is interpreted as a new expression."
  )}
                    </p>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "When using proxy or forward auth (single application) mode, the requested URL Path is checked against the regular expressions. When using forward auth (domain mode), the full requested URL including scheme and host is matched against the regular expressions."
  )}
                    </p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>
        <ak-form-group>
            <span slot="header">${msg("Authentication settings")}</span>
            <div slot="body" class="pf-c-form">
                <ak-switch-input
                    name="interceptHeaderAuth"
                    label=${msg("Intercept header authentication")}
                    ?checked=${provider?.interceptHeaderAuth ?? true}
                    help=${msg(
    "When enabled, authentik will intercept the Authorization header to authenticate the request."
  )}
                >
                </ak-switch-input>

                <ak-switch-input
                    name="basicAuthEnabled"
                    label=${msg("Send HTTP-Basic Authentication")}
                    ?checked=${provider?.basicAuthEnabled ?? false}
                    help=${msg(
    "Send a custom HTTP-Basic Authentication header based on values from authentik."
  )}
                    @change=${onSetShowHttpBasic}
                >
                </ak-switch-input>

                ${showHttpBasic ? renderHttpBasic(provider) : D}
                <ak-form-element-horizontal
                    label=${msg("Federated OIDC Sources")}
                    name="jwtFederationSources"
                >
                    <ak-dual-select-dynamic-selected
                        .provider=${oauth2SourcesProvider}
                        .selector=${oauth2SourcesSelector(provider?.jwtFederationSources)}
                        available-label=${msg("Available Sources")}
                        selected-label=${msg("Selected Sources")}
                    ></ak-dual-select-dynamic-selected>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "JWTs signed by certificates configured in the selected sources can be used to authenticate to this provider."
  )}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Federated OIDC Providers")}
                    name="jwtFederationProviders"
                >
                    <ak-dual-select-dynamic-selected
                        .provider=${oauth2ProvidersProvider2}
                        .selector=${oauth2ProviderSelector(provider?.jwtFederationProviders)}
                        available-label=${msg("Available Providers")}
                        selected-label=${msg("Selected Providers")}
                    ></ak-dual-select-dynamic-selected>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "JWTs signed by the selected providers can be used to authenticate to this provider."
  )}
                    </p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>

        <ak-form-group>
            <span slot="header"> ${msg("Advanced flow settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    label=${msg("Authentication flow")}
                    name="authenticationFlow"
                >
                    <ak-flow-search
                        flowType=${FlowsInstancesListDesignationEnum.Authentication}
                        .currentFlow=${provider?.authenticationFlow}
                    ></ak-flow-search>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "Flow used when a user access this provider and is not authenticated."
  )}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Invalidation flow")}
                    name="invalidationFlow"
                    required
                >
                    <ak-flow-search
                        flowType=${FlowsInstancesListDesignationEnum.Invalidation}
                        .currentFlow=${provider?.invalidationFlow}
                        defaultFlowSlug="default-provider-invalidation-flow"
                        required
                    ></ak-flow-search>
                    <p class="pf-c-form__helper-text">
                        ${msg("Flow used when logging out of this provider.")}
                    </p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>
    `;
}

// src/admin/providers/rac/RACProviderFormHelpers.ts
var mappingToSelect3 = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider3(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderRacList({
    ordering: "name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect3)
  };
}
function propertyMappingsSelector3(instanceMappings) {
  if (!instanceMappings) {
    return async (_mappings) => [];
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsProviderRacRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect3);
  };
}

// src/admin/providers/radius/RadiusProviderFormHelpers.ts
var mappingToSelect4 = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider4(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderRadiusList({
    ordering: "name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect4)
  };
}
function propertyMappingsSelector4(instanceMappings) {
  if (!instanceMappings) {
    return async (_mappings) => [];
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsProviderRadiusRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect4);
  };
}

// src/admin/providers/radius/RadiusProviderFormForm.ts
var mfaSupportHelp2 = msg(
  "When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon."
);
var clientNetworksHelp = msg(
  "List of CIDRs (comma-seperated) that clients can connect from. A more specific CIDR will match before a looser one. Clients connecting from a non-specified CIDR will be dropped."
);
function renderForm4(provider, errors = {}, brand) {
  return ke`
        <ak-text-input
            name="name"
            label=${msg("Name")}
            value=${to(provider?.name)}
            .errorMessages=${errors?.name ?? []}
            required
        >
        </ak-text-input>

        <ak-form-element-horizontal
            label=${msg("Authentication flow")}
            required
            name="authorizationFlow"
            .errorMessages=${errors?.authorizationFlow ?? []}
        >
            <ak-branded-flow-search
                flowType=${FlowsInstancesListDesignationEnum.Authentication}
                .currentFlow=${provider?.authorizationFlow}
                .brandFlow=${brand?.flowAuthentication}
                required
            ></ak-branded-flow-search>
            <p class="pf-c-form__helper-text">${msg("Flow used for users to authenticate.")}</p>
        </ak-form-element-horizontal>

        <ak-switch-input
            name="mfaSupport"
            label=${msg("Code-based MFA Support")}
            ?checked=${provider?.mfaSupport ?? true}
            help=${mfaSupportHelp2}
        >
        </ak-switch-input>

        <ak-form-group expanded>
            <span slot="header"> ${msg("Protocol settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-text-input
                    name="sharedSecret"
                    label=${msg("Shared secret")}
                    .errorMessages=${errors?.sharedSecret ?? []}
                    value=${first(
    provider?.sharedSecret,
    randomString(128, ascii_letters + digits)
  )}
                    required
                    inputHint="code"
                ></ak-text-input>
                <ak-text-input
                    name="clientNetworks"
                    label=${msg("Client Networks")}
                    value=${first(provider?.clientNetworks, "0.0.0.0/0, ::/0")}
                    .errorMessages=${errors?.clientNetworks ?? []}
                    required
                    help=${clientNetworksHelp}
                    inputHint="code"
                ></ak-text-input>
                <ak-form-element-horizontal
                    label=${msg("Property mappings")}
                    name="propertyMappings"
                >
                    <ak-dual-select-dynamic-selected
                        .provider=${propertyMappingsProvider4}
                        .selector=${propertyMappingsSelector4(provider?.propertyMappings)}
                        available-label=${msg("Available Property Mappings")}
                        selected-label=${msg("Selected Property Mappings")}
                    ></ak-dual-select-dynamic-selected>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>
        <ak-form-group>
            <span slot="header"> ${msg("Advanced flow settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    label=${msg("Invalidation flow")}
                    name="invalidationFlow"
                    required
                >
                    <ak-flow-search
                        flowType=${FlowsInstancesListDesignationEnum.Invalidation}
                        .currentFlow=${provider?.invalidationFlow}
                        .errorMessages=${errors?.invalidationFlow ?? []}
                        defaultFlowSlug="default-invalidation-flow"
                        required
                    ></ak-flow-search>
                    <p class="pf-c-form__helper-text">
                        ${msg("Flow used when logging out of this provider.")}
                    </p>
                </ak-form-element-horizontal>
            </div></ak-form-group
        >
    `;
}

// src/admin/providers/saml/SAMLProviderFormHelpers.ts
var mappingToSelect5 = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider5(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderSamlList({
    ordering: "saml_name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect5)
  };
}
function propertyMappingsSelector5(instanceMappings) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(
      ([_0, _1, _2, mapping]) => mapping?.managed?.startsWith("goauthentik.io/providers/saml")
    );
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsProviderSamlRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect5);
  };
}

// src/admin/providers/saml/SAMLProviderOptions.ts
function toOptions(options) {
  return options.map(([label, value, isDefault]) => ({
    label,
    value,
    default: isDefault ?? false
  }));
}
var spBindingOptions = toOptions([
  [msg("Redirect"), SpBindingEnum.Redirect, true],
  [msg("Post"), SpBindingEnum.Post]
]);
var digestAlgorithmOptions = toOptions([
  ["SHA1", DigestAlgorithmEnum.HttpWwwW3Org200009Xmldsigsha1],
  ["SHA256", DigestAlgorithmEnum.HttpWwwW3Org200104Xmlencsha256, true],
  ["SHA384", DigestAlgorithmEnum.HttpWwwW3Org200104XmldsigMoresha384],
  ["SHA512", DigestAlgorithmEnum.HttpWwwW3Org200104Xmlencsha512]
]);
var signatureAlgorithmOptions = toOptions([
  ["RSA-SHA1", SignatureAlgorithmEnum.HttpWwwW3Org200009XmldsigrsaSha1],
  ["RSA-SHA256", SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMorersaSha256, true],
  ["RSA-SHA384", SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMorersaSha384],
  ["RSA-SHA512", SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMorersaSha512],
  ["ECDSA-SHA1", SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMoreecdsaSha1],
  ["ECDSA-SHA256", SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMoreecdsaSha256],
  ["ECDSA-SHA384", SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMoreecdsaSha384],
  ["ECDSA-SHA512", SignatureAlgorithmEnum.HttpWwwW3Org200104XmldsigMoreecdsaSha512],
  ["DSA-SHA1", SignatureAlgorithmEnum.HttpWwwW3Org200009XmldsigdsaSha1]
]);

// src/admin/providers/saml/SAMLProviderFormForm.ts
var serviceProviderBindingOptions = [
  {
    label: msg("Redirect"),
    value: SpBindingEnum.Redirect,
    default: true
  },
  {
    label: msg("Post"),
    value: SpBindingEnum.Post
  }
];
function renderHasSigningKp(provider) {
  return ke` <ak-switch-input
            name="signAssertion"
            label=${msg("Sign assertions")}
            ?checked=${provider?.signAssertion ?? true}
            help=${msg("When enabled, the assertion element of the SAML response will be signed.")}
        >
        </ak-switch-input>

        <ak-switch-input
            name="signResponse"
            label=${msg("Sign responses")}
            ?checked=${provider?.signResponse ?? false}
            help=${msg("When enabled, the assertion element of the SAML response will be signed.")}
        >
        </ak-switch-input>`;
}
function renderForm5(provider = {}, errors, setHasSigningKp, hasSigningKp) {
  return ke` <ak-text-input
            name="name"
            value=${to(provider?.name)}
            label=${msg("Name")}
            required
            .errorMessages=${errors?.name ?? []}
        ></ak-text-input>
        <ak-form-element-horizontal
            name="authorizationFlow"
            label=${msg("Authorization flow")}
            required
        >
            <ak-flow-search
                flowType=${FlowsInstancesListDesignationEnum.Authorization}
                .currentFlow=${provider?.authorizationFlow}
                required
                .errorMessages=${errors?.authorizationFlow ?? []}
            ></ak-flow-search>
            <p class="pf-c-form__helper-text">
                ${msg("Flow used when authorizing this provider.")}
            </p>
        </ak-form-element-horizontal>

        <ak-form-group .expanded=${true}>
            <span slot="header"> ${msg("Protocol settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-text-input
                    name="acsUrl"
                    label=${msg("ACS URL")}
                    value="${to(provider?.acsUrl)}"
                    required
                    .errorMessages=${errors?.acsUrl ?? []}
                ></ak-text-input>
                <ak-text-input
                    label=${msg("Issuer")}
                    name="issuer"
                    value="${provider?.issuer || "authentik"}"
                    required
                    .errorMessages=${errors?.issuer ?? []}
                    help=${msg("Also known as EntityID.")}
                ></ak-text-input>
                <ak-radio-input
                    label=${msg("Service Provider Binding")}
                    name="spBinding"
                    required
                    .options=${serviceProviderBindingOptions}
                    .value=${provider?.spBinding}
                    help=${msg(
    "Determines how authentik sends the response back to the Service Provider."
  )}
                >
                </ak-radio-input>
                <ak-text-input
                    name="audience"
                    label=${msg("Audience")}
                    value="${to(provider?.audience)}"
                    .errorMessages=${errors?.audience ?? []}
                ></ak-text-input>
            </div>
        </ak-form-group>

        <ak-form-group>
            <span slot="header"> ${msg("Advanced flow settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    label=${msg("Authentication flow")}
                    ?required=${false}
                    name="authenticationFlow"
                >
                    <ak-flow-search
                        flowType=${FlowsInstancesListDesignationEnum.Authentication}
                        .currentFlow=${provider?.authenticationFlow}
                    ></ak-flow-search>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "Flow used when a user access this provider and is not authenticated."
  )}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Invalidation flow")}
                    name="invalidationFlow"
                    required
                >
                    <ak-flow-search
                        flowType=${FlowsInstancesListDesignationEnum.Invalidation}
                        .currentFlow=${provider?.invalidationFlow}
                        defaultFlowSlug="default-provider-invalidation-flow"
                        required
                    ></ak-flow-search>
                    <p class="pf-c-form__helper-text">
                        ${msg("Flow used when logging out of this provider.")}
                    </p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>

        <ak-form-group>
            <span slot="header"> ${msg("Advanced protocol settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal label=${msg("Signing Certificate")} name="signingKp">
                    <ak-crypto-certificate-search
                        .certificate=${provider?.signingKp}
                        @input=${setHasSigningKp}
                    ></ak-crypto-certificate-search>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "Certificate used to sign outgoing Responses going to the Service Provider."
  )}
                    </p>
                </ak-form-element-horizontal>
                ${hasSigningKp ? renderHasSigningKp(provider) : D}

                <ak-form-element-horizontal
                    label=${msg("Verification Certificate")}
                    name="verificationKp"
                >
                    <ak-crypto-certificate-search
                        .certificate=${provider?.verificationKp}
                        nokey
                    ></ak-crypto-certificate-search>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "When selected, incoming assertion's Signatures will be validated against this certificate. To allow unsigned Requests, leave on default."
  )}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Encryption Certificate")}
                    name="encryptionKp"
                >
                    <ak-crypto-certificate-search
                        .certificate=${provider?.encryptionKp}
                    ></ak-crypto-certificate-search>
                    <p class="pf-c-form__helper-text">
                        ${msg("When selected, assertions will be encrypted using this keypair.")}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Property mappings")}
                    name="propertyMappings"
                >
                    <ak-dual-select-dynamic-selected
                        .provider=${propertyMappingsProvider5}
                        .selector=${propertyMappingsSelector5(provider?.propertyMappings)}
                        available-label=${msg("Available User Property Mappings")}
                        selected-label=${msg("Selected User Property Mappings")}
                    ></ak-dual-select-dynamic-selected>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("NameID Property Mapping")}
                    name="nameIdMapping"
                >
                    <ak-search-select
                        .fetchObjects=${async (query) => {
    const args = {
      ordering: "saml_name"
    };
    if (query !== void 0) {
      args.search = query;
    }
    const items = await new PropertymappingsApi(
      DEFAULT_CONFIG
    ).propertymappingsProviderSamlList(args);
    return items.results;
  }}
                        .renderElement=${(item) => {
    return item.name;
  }}
                        .value=${(item) => {
    return item?.pk;
  }}
                        .selected=${(item) => {
    return provider?.nameIdMapping === item.pk;
  }}
                        ?blankable=${true}
                    >
                    </ak-search-select>
                    <p class="pf-c-form__helper-text">
                        ${msg(
    "Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be respected."
  )}
                    </p>
                </ak-form-element-horizontal>

                <ak-text-input
                    name="assertionValidNotBefore"
                    label=${msg("Assertion valid not before")}
                    value="${provider?.assertionValidNotBefore || "minutes=-5"}"
                    required
                    .errorMessages=${errors?.assertionValidNotBefore ?? []}
                    help=${msg("Configure the maximum allowed time drift for an assertion.")}
                ></ak-text-input>

                <ak-text-input
                    name="assertionValidNotOnOrAfter"
                    label=${msg("Assertion valid not on or after")}
                    value="${provider?.assertionValidNotOnOrAfter || "minutes=5"}"
                    required
                    .errorMessages=${errors?.assertionValidNotBefore ?? []}
                    help=${msg("Assertion not valid on or after current time + this value.")}
                ></ak-text-input>

                <ak-text-input
                    name="sessionValidNotOnOrAfter"
                    label=${msg("Session valid not on or after")}
                    value="${provider?.sessionValidNotOnOrAfter || "minutes=86400"}"
                    required
                    .errorMessages=${errors?.sessionValidNotOnOrAfter ?? []}
                    help=${msg("Session not valid on or after current time + this value.")}
                ></ak-text-input>

                <ak-text-input
                    name="defaultRelayState"
                    label=${msg("Default relay state")}
                    value="${provider?.defaultRelayState || ""}"
                    .errorMessages=${errors?.sessionValidNotOnOrAfter ?? []}
                    help=${msg(
    "When using IDP-initiated logins, the relay state will be set to this value."
  )}
                ></ak-text-input>

                <ak-radio-input
                    name="digestAlgorithm"
                    label=${msg("Digest algorithm")}
                    .options=${digestAlgorithmOptions}
                    .value=${provider?.digestAlgorithm}
                    required
                >
                </ak-radio-input>

                <ak-radio-input
                    name="signatureAlgorithm"
                    label=${msg("Signature algorithm")}
                    .options=${signatureAlgorithmOptions}
                    .value=${provider?.signatureAlgorithm}
                    required
                >
                </ak-radio-input>
            </div>
        </ak-form-group>`;
}

// src/admin/providers/scim/SCIMProviderFormHelpers.ts
var mappingToSelect6 = (m) => [m.pk, m.name, m.name, m];
async function propertyMappingsProvider6(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderScimList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map(mappingToSelect6)
  };
}
function propertyMappingsSelector6(instanceMappings, defaultSelected) {
  if (!instanceMappings) {
    return async (mappings) => mappings.filter(
      ([_0, _1, _2, mapping]) => mapping?.managed === defaultSelected
    );
  }
  return async () => {
    const pm = new PropertymappingsApi(DEFAULT_CONFIG);
    const mappings = await Promise.allSettled(
      instanceMappings.map(
        (instanceId) => pm.propertymappingsProviderScimRetrieve({ pmUuid: instanceId })
      )
    );
    return mappings.filter((s) => s.status === "fulfilled").map((s) => s.value).map(mappingToSelect6);
  };
}

// src/admin/providers/scim/SCIMProviderFormForm.ts
function renderForm6(provider, errors = {}) {
  return ke`
        <ak-text-input
            name="name"
            value=${to(provider?.name)}
            label=${msg("Name")}
            .errorMessages=${errors?.name ?? []}
            required
            help=${msg("Method's display Name.")}
        ></ak-text-input>
        <ak-form-group expanded>
            <span slot="header"> ${msg("Protocol settings")} </span>
            <div slot="body" class="pf-c-form">
                <ak-text-input
                    name="url"
                    label=${msg("URL")}
                    value="${first(provider?.url, "")}"
                    .errorMessages=${errors?.url ?? []}
                    required
                    help=${msg("SCIM base url, usually ends in /v2.")}
                    inputHint="code"
                ></ak-text-input>

                <ak-switch-input
                    name="verifyCertificates"
                    label=${msg("Verify SCIM server's certificates")}
                    ?checked=${provider?.verifyCertificates ?? true}
                >
                </ak-switch-input>

                <ak-text-input
                    name="token"
                    label=${msg("Token")}
                    value="${provider?.token ?? ""}"
                    .errorMessages=${errors?.token ?? []}
                    required
                    help=${msg(
    "Token to authenticate with. Currently only bearer authentication is supported."
  )}
                    inputHint="code"
                ></ak-text-input>
            </div>
        </ak-form-group>
        <ak-form-group expanded>
            <span slot="header">${msg("User filtering")}</span>
            <div slot="body" class="pf-c-form">
                <ak-switch-input
                    name="excludeUsersServiceAccount"
                    label=${msg("Exclude service accounts")}
                    ?checked=${first(provider?.excludeUsersServiceAccount, true)}
                >
                </ak-switch-input>

                <ak-form-element-horizontal label=${msg("Group")} name="filterGroup">
                    <ak-search-select
                        .fetchObjects=${async (query) => {
    const args = {
      ordering: "name",
      includeUsers: false
    };
    if (query !== void 0) {
      args.search = query;
    }
    const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(args);
    return groups.results;
  }}
                        .renderElement=${(group) => {
    return group.name;
  }}
                        .value=${(group) => {
    return group ? group.pk : void 0;
  }}
                        .selected=${(group) => {
    return group.pk === provider?.filterGroup;
  }}
                        blankable
                    >
                    </ak-search-select>
                    <p class="pf-c-form__helper-text">
                        ${msg("Only sync users within the selected group.")}
                    </p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>

        <ak-form-group expanded>
            <span slot="header"> ${msg("Attribute mapping")} </span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    label=${msg("User Property Mappings")}
                    name="propertyMappings"
                >
                    <ak-dual-select-dynamic-selected
                        .provider=${propertyMappingsProvider6}
                        .selector=${propertyMappingsSelector6(
    provider?.propertyMappings,
    "goauthentik.io/providers/scim/user"
  )}
                        available-label=${msg("Available User Property Mappings")}
                        selected-label=${msg("Selected User Property Mappings")}
                    ></ak-dual-select-dynamic-selected>
                    <p class="pf-c-form__helper-text">
                        ${msg("Property mappings used to user mapping.")}
                    </p>
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Group Property Mappings")}
                    name="propertyMappingsGroup"
                >
                    <ak-dual-select-dynamic-selected
                        .provider=${propertyMappingsProvider6}
                        .selector=${propertyMappingsSelector6(
    provider?.propertyMappingsGroup,
    "goauthentik.io/providers/scim/group"
  )}
                        available-label=${msg("Available Group Property Mappings")}
                        selected-label=${msg("Selected Group Property Mappings")}
                    ></ak-dual-select-dynamic-selected>
                    <p class="pf-c-form__helper-text">
                        ${msg("Property mappings used to group creation.")}
                    </p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>
    `;
}

export {
  renderForm2 as renderForm,
  oauth2ProvidersProvider,
  oauth2ProvidersSelector,
  renderForm as renderForm2,
  BaseProviderForm,
  renderForm3,
  propertyMappingsProvider3 as propertyMappingsProvider,
  propertyMappingsSelector3 as propertyMappingsSelector,
  renderForm4,
  renderForm5,
  renderForm6
};
//# sourceMappingURL=chunk-3B7GTLMQ.js.map
