import {
  AdminApi
} from "./chunk-RRWYRLM7.js";
import {
  PoliciesApi
} from "./chunk-IUFGI55K.js";
import {
  ModelForm
} from "./chunk-3JQ4HF4T.js";
import {
  AKElement,
  DEFAULT_CONFIG,
  EventsApi,
  button_default,
  docLink,
  e,
  first,
  n,
  patternfly_base_default,
  r,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  ke,
  msg,
  str
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/policies/BasePolicyForm.ts
var BasePolicyForm = class extends ModelForm {
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated policy.") : msg("Successfully created policy.");
  }
};

// src/admin/policies/dummy/DummyPolicyForm.ts
var DummyPolicyForm = class extends BasePolicyForm {
  loadInstance(pk) {
    return new PoliciesApi(DEFAULT_CONFIG).policiesDummyRetrieve({
      policyUuid: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new PoliciesApi(DEFAULT_CONFIG).policiesDummyUpdate({
        policyUuid: this.instance.pk || "",
        dummyPolicyRequest: data
      });
    } else {
      return new PoliciesApi(DEFAULT_CONFIG).policiesDummyCreate({
        dummyPolicyRequest: data
      });
    }
  }
  renderForm() {
    return ke` <span>
                ${msg(
      "A policy used for testing. Always returns the same result as specified below after waiting a random duration."
    )}
            </span>
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name || "")}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="executionLogging">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.executionLogging, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Execution logging")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Policy-specific settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="result">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.result, false)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label">${msg("Pass policy?")}</span>
                        </label>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Wait (min)")}
                        ?required=${true}
                        name="waitMin"
                    >
                        <input
                            type="number"
                            value="${first(this.instance?.waitMin, 1)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "The policy takes a random time to execute. This controls the minimum time it will take."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Wait (max)")}
                        ?required=${true}
                        name="waitMax"
                    >
                        <input
                            type="number"
                            value="${first(this.instance?.waitMax, 5)}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
DummyPolicyForm = __decorateClass([
  t("ak-policy-dummy-form")
], DummyPolicyForm);

// src/admin/policies/event_matcher/EventMatcherPolicyForm.ts
var EventMatcherPolicyForm = class extends BasePolicyForm {
  loadInstance(pk) {
    return new PoliciesApi(DEFAULT_CONFIG).policiesEventMatcherRetrieve({
      policyUuid: pk
    });
  }
  async send(data) {
    if (data.action?.toString() === "") data.action = null;
    if (data.clientIp?.toString() === "") data.clientIp = null;
    if (data.app?.toString() === "") data.app = null;
    if (data.model?.toString() === "") data.model = null;
    if (this.instance) {
      return new PoliciesApi(DEFAULT_CONFIG).policiesEventMatcherUpdate({
        policyUuid: this.instance.pk || "",
        eventMatcherPolicyRequest: data
      });
    } else {
      return new PoliciesApi(DEFAULT_CONFIG).policiesEventMatcherCreate({
        eventMatcherPolicyRequest: data
      });
    }
  }
  renderForm() {
    return ke` <span>
                ${msg(
      "Matches an event against a set of criteria. If any of the configured values match, the policy passes."
    )}
            </span>
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name || "")}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="executionLogging">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.executionLogging, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Execution logging")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Policy-specific settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("Action")} name="action">
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const items = await new EventsApi(
        DEFAULT_CONFIG
      ).eventsEventsActionsList();
      return items.filter(
        (item) => query ? item.name.includes(query) : true
      );
    }}
                            .renderElement=${(item) => {
      return item.name;
    }}
                            .value=${(item) => {
      return item?.component;
    }}
                            .selected=${(item) => {
      return this.instance?.action === item.component;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Match created events with this action type. When left empty, all action types will be matched."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Client IP")} name="clientIp">
                        <input
                            type="text"
                            value="${to(this.instance?.clientIp || "")}"
                            class="pf-c-form-control pf-m-monospace"
                            autocomplete="off"
                            spellcheck="false"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Matches Event's Client IP (strict matching, for network matching use an Expression Policy)."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("App")} name="app">
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const items = await new AdminApi(DEFAULT_CONFIG).adminAppsList();
      return items.filter(
        (item) => query ? item.name.includes(query) : true
      );
    }}
                            .renderElement=${(item) => {
      return item.label;
    }}
                            .value=${(item) => {
      return item?.name;
    }}
                            .selected=${(item) => {
      return this.instance?.app === item.name;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Match events created by selected application. When left empty, all applications are matched."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Model")} name="model">
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const items = await new AdminApi(DEFAULT_CONFIG).adminModelsList();
      return items.filter((item) => query ? item.name.includes(query) : true).sort((a, b) => {
        if (a.name < b.name) return -1;
        if (a.name > b.name) return 1;
        return 0;
      });
    }}
                            .renderElement=${(item) => {
      return `${item.label} (${item.name.split(".")[0]})`;
    }}
                            .value=${(item) => {
      return item?.name;
    }}
                            .selected=${(item) => {
      return this.instance?.model === item.name;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Match events created by selected model. When left empty, all models are matched."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
EventMatcherPolicyForm = __decorateClass([
  t("ak-policy-event-matcher-form")
], EventMatcherPolicyForm);

// src/admin/policies/expiry/ExpiryPolicyForm.ts
var PasswordExpiryPolicyForm = class extends BasePolicyForm {
  loadInstance(pk) {
    return new PoliciesApi(DEFAULT_CONFIG).policiesPasswordExpiryRetrieve({
      policyUuid: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new PoliciesApi(DEFAULT_CONFIG).policiesPasswordExpiryUpdate({
        policyUuid: this.instance.pk || "",
        passwordExpiryPolicyRequest: data
      });
    } else {
      return new PoliciesApi(DEFAULT_CONFIG).policiesPasswordExpiryCreate({
        passwordExpiryPolicyRequest: data
      });
    }
  }
  renderForm() {
    return ke` <span>
                ${msg(
      "Checks if the request's user's password has been changed in the last x days, and denys based on settings."
    )}
            </span>
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name || "")}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="executionLogging">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.executionLogging, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Execution logging")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Policy-specific settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Maximum age (in days)")}
                        ?required=${true}
                        name="days"
                    >
                        <input
                            type="number"
                            value="${to(this.instance?.days || "")}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="denyOnly">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.denyOnly, false)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg(
      "Only fail the policy, don't invalidate user's password"
    )}</span
                            >
                        </label>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
PasswordExpiryPolicyForm = __decorateClass([
  t("ak-policy-password-expiry-form")
], PasswordExpiryPolicyForm);

// src/admin/policies/expression/ExpressionPolicyForm.ts
var ExpressionPolicyForm = class extends BasePolicyForm {
  loadInstance(pk) {
    return new PoliciesApi(DEFAULT_CONFIG).policiesExpressionRetrieve({
      policyUuid: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new PoliciesApi(DEFAULT_CONFIG).policiesExpressionUpdate({
        policyUuid: this.instance.pk || "",
        expressionPolicyRequest: data
      });
    } else {
      return new PoliciesApi(DEFAULT_CONFIG).policiesExpressionCreate({
        expressionPolicyRequest: data
      });
    }
  }
  renderForm() {
    return ke` <span>
                ${msg(
      "Executes the python snippet to determine whether to allow or deny a request."
    )}
            </span>
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name || "")}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="executionLogging">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.executionLogging, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Execution logging")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Policy-specific settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Expression")}
                        ?required=${true}
                        name="expression"
                    >
                        <ak-codemirror
                            mode=${"python" /* Python */}
                            value="${to(this.instance?.expression)}"
                        >
                        </ak-codemirror>
                        <p class="pf-c-form__helper-text">
                            ${msg("Expression using Python.")}
                            <a
                                rel="noopener noreferrer"
                                target="_blank"
                                href="${docLink(
      "/docs/customize/policies/expression?utm_source=authentik"
    )}"
                            >
                                ${msg("See documentation for a list of all variables.")}
                            </a>
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
ExpressionPolicyForm = __decorateClass([
  t("ak-policy-expression-form")
], ExpressionPolicyForm);

// src/admin/policies/password/PasswordPolicyForm.ts
var PasswordPolicyForm = class extends BasePolicyForm {
  constructor() {
    super(...arguments);
    this.showStatic = true;
    this.showHIBP = false;
    this.showZxcvbn = false;
  }
  async loadInstance(pk) {
    const policy = await new PoliciesApi(DEFAULT_CONFIG).policiesPasswordRetrieve({
      policyUuid: pk
    });
    this.showStatic = policy.checkStaticRules || false;
    this.showHIBP = policy.checkHaveIBeenPwned || false;
    this.showZxcvbn = policy.checkZxcvbn || false;
    return policy;
  }
  async send(data) {
    if (this.instance) {
      return new PoliciesApi(DEFAULT_CONFIG).policiesPasswordUpdate({
        policyUuid: this.instance.pk || "",
        passwordPolicyRequest: data
      });
    } else {
      return new PoliciesApi(DEFAULT_CONFIG).policiesPasswordCreate({
        passwordPolicyRequest: data
      });
    }
  }
  renderStaticRules() {
    return ke` <ak-form-group>
            <span slot="header"> ${msg("Static rules")} </span>
            <div slot="body" class="pf-c-form">
                <ak-form-element-horizontal
                    label=${msg("Minimum length")}
                    ?required=${true}
                    name="lengthMin"
                >
                    <input
                        type="number"
                        value="${first(this.instance?.lengthMin, 10)}"
                        class="pf-c-form-control"
                        required
                    />
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Minimum amount of Uppercase Characters")}
                    ?required=${true}
                    name="amountUppercase"
                >
                    <input
                        type="number"
                        value="${first(this.instance?.amountUppercase, 2)}"
                        class="pf-c-form-control"
                        required
                    />
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Minimum amount of Lowercase Characters")}
                    ?required=${true}
                    name="amountLowercase"
                >
                    <input
                        type="number"
                        value="${first(this.instance?.amountLowercase, 2)}"
                        class="pf-c-form-control"
                        required
                    />
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Minimum amount of Digits")}
                    ?required=${true}
                    name="amountDigits"
                >
                    <input
                        type="number"
                        value="${first(this.instance?.amountDigits, 2)}"
                        class="pf-c-form-control"
                        required
                    />
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Minimum amount of Symbols Characters")}
                    ?required=${true}
                    name="amountSymbols"
                >
                    <input
                        type="number"
                        value="${first(this.instance?.amountSymbols, 2)}"
                        class="pf-c-form-control"
                        required
                    />
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Error message")}
                    ?required=${true}
                    name="errorMessage"
                >
                    <input
                        type="text"
                        value="${to(this.instance?.errorMessage)}"
                        class="pf-c-form-control"
                        required
                    />
                </ak-form-element-horizontal>
                <ak-form-element-horizontal
                    label=${msg("Symbol charset")}
                    ?required=${true}
                    name="symbolCharset"
                >
                    <input
                        type="text"
                        value="${to(
      this.instance?.symbolCharset || "!\\\"#$%&'()*+,-./:;<=>?@[]^_`{|}~ "
    )}"
                        class="pf-c-form-control"
                        required
                    />
                    <p class="pf-c-form__helper-text">
                        ${msg("Characters which are considered as symbols.")}
                    </p>
                </ak-form-element-horizontal>
            </div>
        </ak-form-group>`;
  }
  renderHIBP() {
    return ke`
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("HaveIBeenPwned settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Allowed count")}
                        ?required=${true}
                        name="hibpAllowedCount"
                    >
                        <input
                            type="number"
                            value="${first(this.instance?.hibpAllowedCount, 0)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Allow up to N occurrences in the HIBP database.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
        `;
  }
  renderZxcvbn() {
    return ke`
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("zxcvbn settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Score threshold")}
                        ?required=${true}
                        name="zxcvbnScoreThreshold"
                    >
                        <input
                            type="number"
                            value="${first(this.instance?.zxcvbnScoreThreshold, 0)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "If the password's score is less than or equal this value, the policy will fail."
    )}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg("0: Too guessable: risky password. (guesses &lt; 10^3)")}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "1: Very guessable: protection from throttled online attacks. (guesses &lt; 10^6)"
    )}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "2: Somewhat guessable: protection from unthrottled online attacks. (guesses &lt; 10^8)"
    )}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "3: Safely unguessable: moderate protection from offline slow-hash scenario. (guesses &lt; 10^10)"
    )}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "4: Very unguessable: strong protection from offline slow-hash scenario. (guesses &gt;= 10^10)"
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
        `;
  }
  renderForm() {
    return ke` <span>
                ${msg(
      "Checks the value from the policy request against several rules, mostly used to ensure password strength."
    )}
            </span>
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name || "")}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="executionLogging">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.executionLogging, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Execution logging")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Password field")}
                ?required=${true}
                name="passwordField"
            >
                <input
                    type="text"
                    value="${to(this.instance?.passwordField || "password")}"
                    class="pf-c-form-control"
                    required
                />
                <p class="pf-c-form__helper-text">
                    ${msg("Field key to check, field keys defined in Prompt stages are available.")}
                </p>
            </ak-form-element-horizontal>

            <ak-form-element-horizontal name="checkStaticRules">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.checkStaticRules, true)}
                        @change=${(ev) => {
      const el = ev.target;
      this.showStatic = el.checked;
    }}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Check static rules")}</span>
                </label>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="checkHaveIBeenPwned">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.checkHaveIBeenPwned, true)}
                        @change=${(ev) => {
      const el = ev.target;
      this.showHIBP = el.checked;
    }}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Check haveibeenpwned.com")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg("For more info see:")}
                    <a href="https://haveibeenpwned.com/API/v2#SearchingPwnedPasswordsByRange"
                        >haveibeenpwned.com</a
                    >
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="checkZxcvbn">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.checkZxcvbn, true)}
                        @change=${(ev) => {
      const el = ev.target;
      this.showZxcvbn = el.checked;
    }}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Check zxcvbn")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg("Password strength estimator created by Dropbox, see:")}
                    <a href="https://github.com/dropbox/zxcvbn#readme">dropbox/zxcvbn</a>
                </p>
            </ak-form-element-horizontal>
            ${this.showStatic ? this.renderStaticRules() : ke``}
            ${this.showHIBP ? this.renderHIBP() : ke``}
            ${this.showZxcvbn ? this.renderZxcvbn() : ke``}`;
  }
};
__decorateClass([
  r()
], PasswordPolicyForm.prototype, "showStatic", 2);
__decorateClass([
  r()
], PasswordPolicyForm.prototype, "showHIBP", 2);
__decorateClass([
  r()
], PasswordPolicyForm.prototype, "showZxcvbn", 2);
PasswordPolicyForm = __decorateClass([
  t("ak-policy-password-form")
], PasswordPolicyForm);

// src/admin/policies/reputation/ReputationPolicyForm.ts
var ReputationPolicyForm = class extends BasePolicyForm {
  loadInstance(pk) {
    return new PoliciesApi(DEFAULT_CONFIG).policiesReputationRetrieve({
      policyUuid: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new PoliciesApi(DEFAULT_CONFIG).policiesReputationUpdate({
        policyUuid: this.instance.pk || "",
        reputationPolicyRequest: data
      });
    } else {
      return new PoliciesApi(DEFAULT_CONFIG).policiesReputationCreate({
        reputationPolicyRequest: data
      });
    }
  }
  renderForm() {
    return ke` <span>
                ${msg("Allows/denys requests based on the users and/or the IPs reputation.")}
            </span>
            <span>
                ${msg(
      `Invalid login attempts will decrease the score for the client's IP, and the
username they are attempting to login as, by one.`
    )}
            </span>
            <span>
                ${msg(
      `The policy passes when the reputation score is below the threshold, and
doesn't pass when either or both of the selected options are equal or above the threshold.`
    )}
            </span>
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name || "")}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="executionLogging">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.executionLogging, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Execution logging")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Policy-specific settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="checkIp">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.checkIp, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label">${msg("Check IP")}</span>
                        </label>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="checkUsername">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.checkUsername, false)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label">${msg("Check Username")}</span>
                        </label>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Threshold")}
                        ?required=${true}
                        name="threshold"
                    >
                        <input
                            type="number"
                            value="${to(this.instance?.threshold || -5)}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
ReputationPolicyForm = __decorateClass([
  t("ak-policy-reputation-form")
], ReputationPolicyForm);

// src/admin/policies/geoip/CountryCache.ts
var CountryCache = class {
  constructor() {
    this.countries = [];
    this.lastReceivedAt = void 0;
    this.TTL = 60 * 1e3;
  }
  async getCountries() {
    const shouldInvalidate = this.lastReceivedAt === void 0 || (/* @__PURE__ */ new Date()).getTime() - this.lastReceivedAt > this.TTL;
    if (!shouldInvalidate) {
      return this.countries;
    }
    await new PoliciesApi(DEFAULT_CONFIG).policiesGeoipIso3166List().then((response) => {
      this.countries = response;
      this.lastReceivedAt = (/* @__PURE__ */ new Date()).getTime();
    });
    return this.countries;
  }
};
var countryCache = new CountryCache();

// src/admin/policies/geoip/GeoIPPolicyForm.ts
function countryToPair(country) {
  return [country.code, country.name];
}
var GeoIPPolicyForm = class extends BasePolicyForm {
  loadInstance(pk) {
    return new PoliciesApi(DEFAULT_CONFIG).policiesGeoipRetrieve({
      policyUuid: pk
    });
  }
  async send(data) {
    if (data.asns?.toString() === "") {
      data.asns = [];
    } else {
      data.asns = data.asns.split(",").map(Number);
    }
    if (this.instance) {
      return new PoliciesApi(DEFAULT_CONFIG).policiesGeoipUpdate({
        policyUuid: this.instance.pk || "",
        geoIPPolicyRequest: data
      });
    } else {
      return new PoliciesApi(DEFAULT_CONFIG).policiesGeoipCreate({
        geoIPPolicyRequest: data
      });
    }
  }
  renderForm() {
    return ke`<span>
                ${msg(
      "Ensure the user satisfies requirements of geography or network topology, based on IP address. If any of the configured values match, the policy passes."
    )}
            </span>
            <ak-form-element-horizontal label=${msg("Name")} required name="name">
                <input
                    type="text"
                    value="${this.instance?.name ?? ""}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="executionLogging">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${this.instance?.executionLogging ?? false}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Execution logging")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-group>
                <span slot="header"> ${msg("Distance settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="checkHistoryDistance">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${this.instance?.checkHistoryDistance ?? false}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Check historical distance of logins")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When this option enabled, the GeoIP data of the policy request is compared to the specified number of historical logins."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Maximum distance")}
                        name="historyMaxDistanceKm"
                    >
                        <input
                            type="number"
                            min="1"
                            value="${first(this.instance?.historyMaxDistanceKm, 100)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Maximum distance a login attempt is allowed from in kilometers."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Distance tolerance")}
                        name="distanceToleranceKm"
                    >
                        <input
                            type="number"
                            min="1"
                            value="${first(this.instance?.distanceToleranceKm, 50)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Tolerance in checking for distances in kilometers.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Historical Login Count")}
                        name="historyLoginCount"
                    >
                        <input
                            type="number"
                            min="1"
                            value="${first(this.instance?.historyLoginCount, 5)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Amount of previous login events to check against.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="checkImpossibleTravel">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${this.instance?.checkImpossibleTravel ?? true}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Check impossible travel")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When this option enabled, the GeoIP data of the policy request is compared to the specified number of historical logins and if the travel would have been possible in the amount of time since the previous event."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Impossible travel tolerance")}
                        name="impossibleToleranceKm"
                    >
                        <input
                            type="number"
                            min="1"
                            value="${first(this.instance?.impossibleToleranceKm, 50)}"
                            class="pf-c-form-control"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Tolerance in checking for distances in kilometers.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header">${msg("Static rule settings")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("ASNs")} name="asns">
                        <input
                            type="text"
                            value="${this.instance?.asns?.join(",") ?? ""}"
                            class="pf-c-form-control pf-m-monospace"
                            autocomplete="off"
                            spellcheck="false"
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "List of autonomous system numbers. Comma separated. E.g. 13335, 15169, 20940"
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Countries")} name="countries">
                        <ak-dual-select-provider
                            .provider=${(page, search) => {
      return countryCache.getCountries().then((results) => {
        if (!search) return results;
        return results.filter(
          (result) => result.name.toLowerCase().includes(search.toLowerCase())
        );
      }).then((results) => {
        return {
          options: results.map(countryToPair)
        };
      });
    }}
                            .selected=${(this.instance?.countriesObj ?? []).map(countryToPair)}
                            available-label="${msg("Available Countries")}"
                            selected-label="${msg("Selected Countries")}"
                        >
                        </ak-dual-select-provider>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
GeoIPPolicyForm = __decorateClass([
  t("ak-policy-geoip-form")
], GeoIPPolicyForm);

// src/admin/policies/PolicyWizard.ts
var PolicyWizard = class extends AKElement {
  constructor() {
    super(...arguments);
    this.createText = msg("Create");
    this.showBindingPage = false;
    this.policyTypes = [];
    this.selectListener = ({ detail }) => {
      if (!this.wizard) return;
      const { component, modelName } = detail;
      const idx = this.wizard.steps.indexOf("initial") + 1;
      this.wizard.steps = this.wizard.steps.filter((step) => !step.startsWith("type-"));
      this.wizard.steps.splice(idx, 0, `type-${component}-${modelName}`);
      this.wizard.isValid = true;
    };
  }
  static get styles() {
    return [patternfly_base_default, button_default];
  }
  firstUpdated() {
    new PoliciesApi(DEFAULT_CONFIG).policiesAllTypesList().then((types) => {
      this.policyTypes = types;
    });
  }
  render() {
    return ke`
            <ak-wizard
                .steps=${this.showBindingPage ? ["initial", "create-binding"] : ["initial"]}
                header=${msg("New policy")}
                description=${msg("Create a new policy.")}
            >
                <ak-wizard-page-type-create
                    slot="initial"
                    .types=${this.policyTypes}
                    @select=${this.selectListener}
                >
                </ak-wizard-page-type-create>

                ${this.policyTypes.map((type) => {
      return ke`
                        <ak-wizard-page-form
                            slot=${`type-${type.component}-${type.modelName}`}
                            .sidebarLabel=${() => msg(str`Create ${type.name}`)}
                        >
                            <ak-proxy-form type=${type.component}></ak-proxy-form>
                        </ak-wizard-page-form>
                    `;
    })}
                ${this.showBindingPage ? ke`<ak-wizard-page-form
                          slot="create-binding"
                          .sidebarLabel=${() => msg("Create Binding")}
                          .activePageCallback=${async (context) => {
      const createSlot = context.host.steps[1];
      const bindingForm = context.querySelector(
        "ak-policy-binding-form"
      );
      if (!bindingForm) return;
      bindingForm.instance = {
        policy: context.host.state[createSlot].pk
      };
    }}
                      >
                          <ak-policy-binding-form
                              .targetPk=${this.bindingTarget}
                          ></ak-policy-binding-form>
                      </ak-wizard-page-form>` : ke``}
                <button slot="trigger" class="pf-c-button pf-m-primary">${this.createText}</button>
            </ak-wizard>
        `;
  }
};
__decorateClass([
  n()
], PolicyWizard.prototype, "createText", 2);
__decorateClass([
  n({ type: Boolean })
], PolicyWizard.prototype, "showBindingPage", 2);
__decorateClass([
  n()
], PolicyWizard.prototype, "bindingTarget", 2);
__decorateClass([
  n({ attribute: false })
], PolicyWizard.prototype, "policyTypes", 2);
__decorateClass([
  e("ak-wizard")
], PolicyWizard.prototype, "wizard", 2);
PolicyWizard = __decorateClass([
  t("ak-policy-wizard")
], PolicyWizard);
//# sourceMappingURL=chunk-7CZKKH2O.js.map
