import {
  card_default
} from "./chunk-ITYWTYEW.js";
import {
  Table,
  TableColumn
} from "./chunk-APZGZXW5.js";
import {
  table_default
} from "./chunk-K3AR7TXW.js";
import {
  AKElement,
  EVENT_REFRESH,
  SystemTaskStatusEnum,
  getRelativeTime,
  n,
  patternfly_base_default,
  r,
  t
} from "./chunk-MKGIUSP2.js";
import {
  i,
  ke,
  msg
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/elements/sync/SyncStatusCard.ts
var SyncStatusTable = class extends Table {
  constructor() {
    super(...arguments);
    this.tasks = [];
    this.expandable = true;
  }
  static get styles() {
    return super.styles.concat(i`
            code:not(:last-of-type)::after {
                content: "-";
                margin: 0 0.25rem;
            }
        `);
  }
  async apiEndpoint() {
    return {
      pagination: {
        next: 0,
        previous: 0,
        count: this.tasks.length,
        current: 1,
        totalPages: 1,
        startIndex: 0,
        endIndex: this.tasks.length
      },
      results: this.tasks
    };
  }
  columns() {
    return [
      new TableColumn(msg("Task")),
      new TableColumn(msg("Status")),
      new TableColumn(msg("Finished"))
    ];
  }
  row(item) {
    const nameParts = item.fullName.split(":");
    nameParts.shift();
    return [
      ke`<div>${item.name}</div>
                <small>${nameParts.map((part) => ke`<code>${part}</code>`)}</small>`,
      ke`<ak-status-label
                ?good=${item.status === SystemTaskStatusEnum.Successful}
                good-label=${msg("Finished successfully")}
                bad-label=${msg("Finished with errors")}
            ></ak-status-label>`,
      ke`<div>${getRelativeTime(item.finishTimestamp)}</div>
                <small>${item.finishTimestamp.toLocaleString()}</small>`
    ];
  }
  renderExpanded(item) {
    return ke`<td role="cell" colspan="4">
            <div class="pf-c-table__expandable-row-content">
                <ak-log-viewer .logs=${item?.messages}></ak-log-viewer>
            </div>
        </td>`;
  }
  renderToolbarContainer() {
    return ke``;
  }
  renderTablePagination() {
    return ke``;
  }
};
__decorateClass([
  n({ attribute: false })
], SyncStatusTable.prototype, "tasks", 2);
SyncStatusTable = __decorateClass([
  t("ak-sync-status-table")
], SyncStatusTable);
var SyncStatusCard = class extends AKElement {
  constructor() {
    super(...arguments);
    this.loading = false;
  }
  static get styles() {
    return [patternfly_base_default, card_default, table_default];
  }
  firstUpdated() {
    this.loading = true;
    this.fetch().then((status) => {
      this.syncState = status;
      this.loading = false;
    });
  }
  renderSyncStatus() {
    if (this.loading) {
      return ke`<ak-empty-state ?loading=${true}></ak-empty-state>`;
    }
    if (!this.syncState) {
      return ke`${msg("No sync status.")}`;
    }
    if (this.syncState.isRunning) {
      return ke`${msg("Sync currently running.")}`;
    }
    if (this.syncState.tasks.length < 1) {
      return ke`${msg("Not synced yet.")}`;
    }
    return ke`<ak-sync-status-table .tasks=${this.syncState.tasks}></ak-sync-status-table>`;
  }
  render() {
    return ke`<div class="pf-c-card">
            <div class="pf-c-card__title">${msg("Sync status")}</div>
            <div class="pf-c-card__body">${this.renderSyncStatus()}</div>
            <div class="pf-c-card__footer">
                <ak-action-button
                    class="pf-m-secondary"
                    ?disabled=${this.syncState?.isRunning}
                    .apiRequest=${() => {
      if (this.syncState) {
        this.syncState = {
          ...this.syncState,
          isRunning: true
        };
      }
      this.triggerSync().then(() => {
        this.dispatchEvent(
          new CustomEvent(EVENT_REFRESH, {
            bubbles: true,
            composed: true
          })
        );
        this.firstUpdated();
      });
    }}
                >
                    ${this.syncState?.isRunning ? msg("Sync currently running") : msg("Run sync again")}
                </ak-action-button>
            </div>
        </div>`;
  }
};
__decorateClass([
  r()
], SyncStatusCard.prototype, "syncState", 2);
__decorateClass([
  r()
], SyncStatusCard.prototype, "loading", 2);
__decorateClass([
  n({ attribute: false })
], SyncStatusCard.prototype, "fetch", 2);
__decorateClass([
  n({ attribute: false })
], SyncStatusCard.prototype, "triggerSync", 2);
SyncStatusCard = __decorateClass([
  t("ak-sync-status-card")
], SyncStatusCard);
//# sourceMappingURL=chunk-FKTDWPGA.js.map
