import {
  StagesApi
} from "./chunk-AVWUV543.js";
import {
  Form
} from "./chunk-Y4CBTB76.js";
import {
  ModalButton
} from "./chunk-DK5NYREA.js";
import {
  be,
  list_default
} from "./chunk-43ID2PET.js";
import {
  CoreApi,
  DEFAULT_CONFIG,
  EVENT_REFRESH,
  UsedByActionEnum,
  dateTimeLocal,
  globalAK,
  groupBy,
  n,
  showMessage,
  t,
  to
} from "./chunk-MKGIUSP2.js";
import {
  ke,
  msg,
  str
} from "./chunk-BW7LVHGS.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/users/ServiceAccountForm.ts
var ServiceAccountForm = class extends Form {
  getSuccessMessage() {
    if (this.group) {
      return msg(str`Successfully created user and added to group ${this.group.name}`);
    }
    return msg("Successfully created user.");
  }
  async send(data) {
    const result = await new CoreApi(DEFAULT_CONFIG).coreUsersServiceAccountCreate({
      userServiceAccountRequest: data
    });
    this.result = result;
    this.parentElement.showSubmitButton = false;
    if (this.group) {
      await new CoreApi(DEFAULT_CONFIG).coreGroupsAddUserCreate({
        groupUuid: this.group.pk,
        userAccountRequest: {
          pk: this.result.userPk
        }
      });
    }
    return result;
  }
  resetForm() {
    super.resetForm();
    this.result = void 0;
  }
  renderForm() {
    return ke`<ak-form-element-horizontal
                label=${msg("Username")}
                ?required=${true}
                name="name"
            >
                <input
                    type="text"
                    value=""
                    class="pf-c-form-control pf-m-monospace"
                    autocomplete="off"
                    spellcheck="false"
                    required
                />
                <p class="pf-c-form__helper-text">
                    ${msg("User's primary identifier. 150 characters or fewer.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="createGroup">
                <label class="pf-c-switch">
                    <input class="pf-c-switch__input" type="checkbox" ?checked=${true} />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Create group")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Enabling this toggle will create a group named after the user, with the user as member."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="expiring">
                <label class="pf-c-switch">
                    <input class="pf-c-switch__input" type="checkbox" ?checked=${true} />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Expiring")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "If this is selected, the token will expire. Upon expiration, the token will be rotated."
    )}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Expires on")} name="expires">
                <input
                    type="datetime-local"
                    data-type="datetime-local"
                    value="${dateTimeLocal(new Date(Date.now() + 1e3 * 60 ** 2 * 24 * 360))}"
                    class="pf-c-form-control"
                />
            </ak-form-element-horizontal>`;
  }
  renderResponseForm() {
    return ke`<p>
                ${msg(
      "Use the username and password below to authenticate. The password can be retrieved later on the Tokens page."
    )}
            </p>
            <form class="pf-c-form pf-m-horizontal">
                <ak-form-element-horizontal label=${msg("Username")}>
                    <input
                        type="text"
                        readonly
                        value=${to(this.result?.username)}
                        class="pf-c-form-control"
                    />
                </ak-form-element-horizontal>
                <ak-form-element-horizontal label=${msg("Password")}>
                    <input
                        type="text"
                        readonly
                        value=${to(this.result?.token)}
                        class="pf-c-form-control"
                    />
                    <p class="pf-c-form__helper-text">
                        ${msg(
      "Valid for 360 days, after which the password will automatically rotate. You can copy the password from the Token List."
    )}
                    </p>
                </ak-form-element-horizontal>
            </form>`;
  }
  renderFormWrapper() {
    if (this.result) {
      return this.renderResponseForm();
    }
    return super.renderFormWrapper();
  }
};
__decorateClass([
  n({ attribute: false })
], ServiceAccountForm.prototype, "result", 2);
__decorateClass([
  n({ attribute: false })
], ServiceAccountForm.prototype, "group", 2);
ServiceAccountForm = __decorateClass([
  t("ak-user-service-account-form")
], ServiceAccountForm);

// src/elements/forms/DeleteForm.ts
var DeleteForm = class extends ModalButton {
  static get styles() {
    return super.styles.concat(list_default);
  }
  confirm() {
    return this.delete().then(() => {
      this.onSuccess();
      this.open = false;
      this.dispatchEvent(
        new CustomEvent(EVENT_REFRESH, {
          bubbles: true,
          composed: true
        })
      );
    }).catch((e) => {
      this.onError(e);
      throw e;
    });
  }
  onSuccess() {
    showMessage({
      message: msg(str`Successfully deleted ${this.objectLabel} ${this.obj?.name}`),
      level: "success" /* success */
    });
  }
  onError(e) {
    showMessage({
      message: msg(str`Failed to delete ${this.objectLabel}: ${e.toString()}`),
      level: "error" /* error */
    });
  }
  renderModalInner() {
    let objName = this.obj?.name;
    if (objName) {
      objName = ` "${objName}"`;
    } else {
      objName = "";
    }
    return ke`<section class="pf-c-modal-box__header pf-c-page__main-section pf-m-light">
                <div class="pf-c-content">
                    <h1 class="pf-c-title pf-m-2xl">${msg(str`Delete ${this.objectLabel}`)}</h1>
                </div>
            </section>
            <section class="pf-c-modal-box__body pf-m-light">
                <form class="pf-c-form pf-m-horizontal">
                    <p>
                        ${msg(str`Are you sure you want to delete ${this.objectLabel} ${objName}?`)}
                    </p>
                </form>
            </section>
            ${this.usedBy ? be(
      this.usedBy().then((usedBy) => {
        if (usedBy.length < 1) {
          return ke``;
        }
        return ke`
                              <section class="pf-c-modal-box__body pf-m-light">
                                  <form class="pf-c-form pf-m-horizontal">
                                      <p>${msg(str`The following objects use ${objName}`)}</p>
                                      <ul class="pf-c-list">
                                          ${usedBy.map((ub) => {
          let consequence = "";
          switch (ub.action) {
            case UsedByActionEnum.Cascade:
              consequence = msg("object will be DELETED");
              break;
            case UsedByActionEnum.CascadeMany:
              consequence = msg(
                "connecting object will be deleted"
              );
              break;
            case UsedByActionEnum.SetDefault:
              consequence = msg(
                "reference will be reset to default value"
              );
              break;
            case UsedByActionEnum.SetNull:
              consequence = msg(
                "reference will be set to an empty value"
              );
              break;
          }
          return ke`<li>
                                                  ${msg(str`${ub.name} (${consequence})`)}
                                              </li>`;
        })}
                                      </ul>
                                  </form>
                              </section>
                          `;
      })
    ) : ke``}
            <footer class="pf-c-modal-box__footer">
                <ak-spinner-button
                    .callAction=${() => {
      return this.confirm();
    }}
                    class="pf-m-danger"
                >
                    ${msg("Delete")} </ak-spinner-button
                >&nbsp;
                <ak-spinner-button
                    .callAction=${async () => {
      this.open = false;
    }}
                    class="pf-m-secondary"
                >
                    ${msg("Cancel")}
                </ak-spinner-button>
            </footer>`;
  }
};
__decorateClass([
  n({ attribute: false })
], DeleteForm.prototype, "obj", 2);
__decorateClass([
  n()
], DeleteForm.prototype, "objectLabel", 2);
__decorateClass([
  n({ attribute: false })
], DeleteForm.prototype, "usedBy", 2);
__decorateClass([
  n({ attribute: false })
], DeleteForm.prototype, "delete", 2);
DeleteForm = __decorateClass([
  t("ak-forms-delete")
], DeleteForm);

// src/admin/users/UserActiveForm.ts
var UserActiveForm = class extends DeleteForm {
  onSuccess() {
    showMessage({
      message: msg(str`Successfully updated ${this.objectLabel} ${this.obj?.name}`),
      level: "success" /* success */
    });
  }
  onError(e) {
    showMessage({
      message: msg(str`Failed to update ${this.objectLabel}: ${e.toString()}`),
      level: "error" /* error */
    });
  }
  renderModalInner() {
    return ke`<section class="pf-c-modal-box__header pf-c-page__main-section pf-m-light">
                <div class="pf-c-content">
                    <h1 class="pf-c-title pf-m-2xl">${msg(str`Update ${this.objectLabel}`)}</h1>
                </div>
            </section>
            <section class="pf-c-modal-box__body pf-m-light">
                <form class="pf-c-form pf-m-horizontal">
                    <p>
                        ${msg(
      str`Are you sure you want to update ${this.objectLabel} "${this.obj?.name}"?`
    )}
                    </p>
                </form>
            </section>
            <footer class="pf-c-modal-box__footer">
                <ak-spinner-button
                    .callAction=${() => {
      return this.confirm();
    }}
                    class="pf-m-warning"
                >
                    ${msg("Update")} </ak-spinner-button
                >&nbsp;
                <ak-spinner-button
                    .callAction=${async () => {
      this.open = false;
    }}
                    class="pf-m-secondary"
                >
                    ${msg("Cancel")}
                </ak-spinner-button>
            </footer>`;
  }
};
UserActiveForm = __decorateClass([
  t("ak-user-active-form")
], UserActiveForm);

// src/admin/users/UserImpersonateForm.ts
var UserImpersonateForm = class extends Form {
  async send(data) {
    return new CoreApi(DEFAULT_CONFIG).coreUsersImpersonateCreate({
      id: this.instancePk || 0,
      impersonationRequest: data
    }).then(() => {
      window.location.href = globalAK().api.base;
    });
  }
  renderForm() {
    return ke`<ak-text-input
            name="reason"
            label=${msg("Reason")}
            help=${msg("Reason for impersonating the user")}
        ></ak-text-input>`;
  }
};
__decorateClass([
  n({ type: Number })
], UserImpersonateForm.prototype, "instancePk", 2);
UserImpersonateForm = __decorateClass([
  t("ak-user-impersonate-form")
], UserImpersonateForm);

// src/admin/users/UserPasswordForm.ts
var UserPasswordForm = class extends Form {
  getSuccessMessage() {
    return msg("Successfully updated password.");
  }
  async send(data) {
    return new CoreApi(DEFAULT_CONFIG).coreUsersSetPasswordCreate({
      id: this.instancePk || 0,
      userPasswordSetRequest: data
    });
  }
  renderForm() {
    return ke`<ak-form-element-horizontal
            label=${msg("Password")}
            ?required=${true}
            name="password"
        >
            <input type="password" value="" class="pf-c-form-control" required />
        </ak-form-element-horizontal>`;
  }
};
__decorateClass([
  n({ type: Number })
], UserPasswordForm.prototype, "instancePk", 2);
UserPasswordForm = __decorateClass([
  t("ak-user-password-form")
], UserPasswordForm);

// src/admin/users/UserResetEmailForm.ts
var UserResetEmailForm = class extends Form {
  getSuccessMessage() {
    return msg("Successfully sent email.");
  }
  async send(data) {
    data.id = this.user.pk;
    return new CoreApi(DEFAULT_CONFIG).coreUsersRecoveryEmailCreate(data);
  }
  renderForm() {
    return ke`<ak-form-element-horizontal
            label=${msg("Email stage")}
            ?required=${true}
            name="emailStage"
        >
            <ak-search-select
                .fetchObjects=${async (query) => {
      const args = {
        ordering: "name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const stages = await new StagesApi(DEFAULT_CONFIG).stagesEmailList(args);
      return stages.results;
    }}
                .groupBy=${(items) => {
      return groupBy(items, (stage) => stage.verboseNamePlural);
    }}
                .renderElement=${(stage) => {
      return stage.name;
    }}
                .value=${(stage) => {
      return stage?.pk;
    }}
            >
            </ak-search-select>
        </ak-form-element-horizontal>`;
  }
};
__decorateClass([
  n({ attribute: false })
], UserResetEmailForm.prototype, "user", 2);
UserResetEmailForm = __decorateClass([
  t("ak-user-reset-email-form")
], UserResetEmailForm);
//# sourceMappingURL=chunk-YFKWY7VQ.js.map
